"""InterMountableComponentConnectionCompoundModalAnalysis"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List

from mastapy._internal import conversion
from mastapy.system_model.analyses_and_results.modal_analyses.compound import _4763
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_INTER_MOUNTABLE_COMPONENT_CONNECTION_COMPOUND_MODAL_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalyses.Compound",
    "InterMountableComponentConnectionCompoundModalAnalysis",
)

if TYPE_CHECKING:
    from mastapy.system_model.analyses_and_results.modal_analyses import _4642
    from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
        _4733,
        _4737,
        _4740,
        _4745,
        _4750,
        _4755,
        _4758,
        _4761,
        _4766,
        _4768,
        _4776,
        _4782,
        _4787,
        _4791,
        _4795,
        _4798,
        _4801,
        _4809,
        _4818,
        _4821,
        _4828,
        _4831,
        _4834,
        _4837,
        _4846,
        _4852,
        _4855,
    )
    from mastapy.system_model.analyses_and_results.analysis_cases import _7539, _7543
    from mastapy.system_model.analyses_and_results import _2651


__docformat__ = "restructuredtext en"
__all__ = ("InterMountableComponentConnectionCompoundModalAnalysis",)


Self = TypeVar("Self", bound="InterMountableComponentConnectionCompoundModalAnalysis")


class InterMountableComponentConnectionCompoundModalAnalysis(
    _4763.ConnectionCompoundModalAnalysis
):
    """InterMountableComponentConnectionCompoundModalAnalysis

    This is a mastapy class.
    """

    TYPE = _INTER_MOUNTABLE_COMPONENT_CONNECTION_COMPOUND_MODAL_ANALYSIS
    _CastSelf = TypeVar(
        "_CastSelf",
        bound="_Cast_InterMountableComponentConnectionCompoundModalAnalysis",
    )

    class _Cast_InterMountableComponentConnectionCompoundModalAnalysis:
        """Special nested class for casting InterMountableComponentConnectionCompoundModalAnalysis to subclasses."""

        def __init__(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
            parent: "InterMountableComponentConnectionCompoundModalAnalysis",
        ):
            self._parent = parent

        @property
        def connection_compound_modal_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_4763.ConnectionCompoundModalAnalysis":
            return self._parent._cast(_4763.ConnectionCompoundModalAnalysis)

        @property
        def connection_compound_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_7539.ConnectionCompoundAnalysis":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7539

            return self._parent._cast(_7539.ConnectionCompoundAnalysis)

        @property
        def design_entity_compound_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_7543.DesignEntityCompoundAnalysis":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7543

            return self._parent._cast(_7543.DesignEntityCompoundAnalysis)

        @property
        def design_entity_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_2651.DesignEntityAnalysis":
            from mastapy.system_model.analyses_and_results import _2651

            return self._parent._cast(_2651.DesignEntityAnalysis)

        @property
        def agma_gleason_conical_gear_mesh_compound_modal_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_4733.AGMAGleasonConicalGearMeshCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4733,
            )

            return self._parent._cast(
                _4733.AGMAGleasonConicalGearMeshCompoundModalAnalysis
            )

        @property
        def belt_connection_compound_modal_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_4737.BeltConnectionCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4737,
            )

            return self._parent._cast(_4737.BeltConnectionCompoundModalAnalysis)

        @property
        def bevel_differential_gear_mesh_compound_modal_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_4740.BevelDifferentialGearMeshCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4740,
            )

            return self._parent._cast(
                _4740.BevelDifferentialGearMeshCompoundModalAnalysis
            )

        @property
        def bevel_gear_mesh_compound_modal_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_4745.BevelGearMeshCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4745,
            )

            return self._parent._cast(_4745.BevelGearMeshCompoundModalAnalysis)

        @property
        def clutch_connection_compound_modal_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_4750.ClutchConnectionCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4750,
            )

            return self._parent._cast(_4750.ClutchConnectionCompoundModalAnalysis)

        @property
        def concept_coupling_connection_compound_modal_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_4755.ConceptCouplingConnectionCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4755,
            )

            return self._parent._cast(
                _4755.ConceptCouplingConnectionCompoundModalAnalysis
            )

        @property
        def concept_gear_mesh_compound_modal_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_4758.ConceptGearMeshCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4758,
            )

            return self._parent._cast(_4758.ConceptGearMeshCompoundModalAnalysis)

        @property
        def conical_gear_mesh_compound_modal_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_4761.ConicalGearMeshCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4761,
            )

            return self._parent._cast(_4761.ConicalGearMeshCompoundModalAnalysis)

        @property
        def coupling_connection_compound_modal_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_4766.CouplingConnectionCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4766,
            )

            return self._parent._cast(_4766.CouplingConnectionCompoundModalAnalysis)

        @property
        def cvt_belt_connection_compound_modal_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_4768.CVTBeltConnectionCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4768,
            )

            return self._parent._cast(_4768.CVTBeltConnectionCompoundModalAnalysis)

        @property
        def cylindrical_gear_mesh_compound_modal_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_4776.CylindricalGearMeshCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4776,
            )

            return self._parent._cast(_4776.CylindricalGearMeshCompoundModalAnalysis)

        @property
        def face_gear_mesh_compound_modal_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_4782.FaceGearMeshCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4782,
            )

            return self._parent._cast(_4782.FaceGearMeshCompoundModalAnalysis)

        @property
        def gear_mesh_compound_modal_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_4787.GearMeshCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4787,
            )

            return self._parent._cast(_4787.GearMeshCompoundModalAnalysis)

        @property
        def hypoid_gear_mesh_compound_modal_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_4791.HypoidGearMeshCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4791,
            )

            return self._parent._cast(_4791.HypoidGearMeshCompoundModalAnalysis)

        @property
        def klingelnberg_cyclo_palloid_conical_gear_mesh_compound_modal_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_4795.KlingelnbergCycloPalloidConicalGearMeshCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4795,
            )

            return self._parent._cast(
                _4795.KlingelnbergCycloPalloidConicalGearMeshCompoundModalAnalysis
            )

        @property
        def klingelnberg_cyclo_palloid_hypoid_gear_mesh_compound_modal_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_4798.KlingelnbergCycloPalloidHypoidGearMeshCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4798,
            )

            return self._parent._cast(
                _4798.KlingelnbergCycloPalloidHypoidGearMeshCompoundModalAnalysis
            )

        @property
        def klingelnberg_cyclo_palloid_spiral_bevel_gear_mesh_compound_modal_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_4801.KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4801,
            )

            return self._parent._cast(
                _4801.KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundModalAnalysis
            )

        @property
        def part_to_part_shear_coupling_connection_compound_modal_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_4809.PartToPartShearCouplingConnectionCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4809,
            )

            return self._parent._cast(
                _4809.PartToPartShearCouplingConnectionCompoundModalAnalysis
            )

        @property
        def ring_pins_to_disc_connection_compound_modal_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_4818.RingPinsToDiscConnectionCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4818,
            )

            return self._parent._cast(
                _4818.RingPinsToDiscConnectionCompoundModalAnalysis
            )

        @property
        def rolling_ring_connection_compound_modal_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_4821.RollingRingConnectionCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4821,
            )

            return self._parent._cast(_4821.RollingRingConnectionCompoundModalAnalysis)

        @property
        def spiral_bevel_gear_mesh_compound_modal_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_4828.SpiralBevelGearMeshCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4828,
            )

            return self._parent._cast(_4828.SpiralBevelGearMeshCompoundModalAnalysis)

        @property
        def spring_damper_connection_compound_modal_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_4831.SpringDamperConnectionCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4831,
            )

            return self._parent._cast(_4831.SpringDamperConnectionCompoundModalAnalysis)

        @property
        def straight_bevel_diff_gear_mesh_compound_modal_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_4834.StraightBevelDiffGearMeshCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4834,
            )

            return self._parent._cast(
                _4834.StraightBevelDiffGearMeshCompoundModalAnalysis
            )

        @property
        def straight_bevel_gear_mesh_compound_modal_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_4837.StraightBevelGearMeshCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4837,
            )

            return self._parent._cast(_4837.StraightBevelGearMeshCompoundModalAnalysis)

        @property
        def torque_converter_connection_compound_modal_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_4846.TorqueConverterConnectionCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4846,
            )

            return self._parent._cast(
                _4846.TorqueConverterConnectionCompoundModalAnalysis
            )

        @property
        def worm_gear_mesh_compound_modal_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_4852.WormGearMeshCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4852,
            )

            return self._parent._cast(_4852.WormGearMeshCompoundModalAnalysis)

        @property
        def zerol_bevel_gear_mesh_compound_modal_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "_4855.ZerolBevelGearMeshCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4855,
            )

            return self._parent._cast(_4855.ZerolBevelGearMeshCompoundModalAnalysis)

        @property
        def inter_mountable_component_connection_compound_modal_analysis(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
        ) -> "InterMountableComponentConnectionCompoundModalAnalysis":
            return self._parent

        def __getattr__(
            self: "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(
        self: Self,
        instance_to_wrap: "InterMountableComponentConnectionCompoundModalAnalysis.TYPE",
    ):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def connection_analysis_cases(
        self: Self,
    ) -> "List[_4642.InterMountableComponentConnectionModalAnalysis]":
        """List[mastapy.system_model.analyses_and_results.modal_analyses.InterMountableComponentConnectionModalAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectionAnalysisCases

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def connection_analysis_cases_ready(
        self: Self,
    ) -> "List[_4642.InterMountableComponentConnectionModalAnalysis]":
        """List[mastapy.system_model.analyses_and_results.modal_analyses.InterMountableComponentConnectionModalAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectionAnalysisCasesReady

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(
        self: Self,
    ) -> "InterMountableComponentConnectionCompoundModalAnalysis._Cast_InterMountableComponentConnectionCompoundModalAnalysis":
        return self._Cast_InterMountableComponentConnectionCompoundModalAnalysis(self)



"""__init__.py"""

import sys
from typing import TYPE_CHECKING

from lazy_imports import LazyImporter


if TYPE_CHECKING:
    from ._6543 import AbstractAssemblyCriticalSpeedAnalysis
    from ._6544 import AbstractShaftCriticalSpeedAnalysis
    from ._6545 import AbstractShaftOrHousingCriticalSpeedAnalysis
    from ._6546 import AbstractShaftToMountableComponentConnectionCriticalSpeedAnalysis
    from ._6547 import AGMAGleasonConicalGearCriticalSpeedAnalysis
    from ._6548 import AGMAGleasonConicalGearMeshCriticalSpeedAnalysis
    from ._6549 import AGMAGleasonConicalGearSetCriticalSpeedAnalysis
    from ._6550 import AssemblyCriticalSpeedAnalysis
    from ._6551 import BearingCriticalSpeedAnalysis
    from ._6552 import BeltConnectionCriticalSpeedAnalysis
    from ._6553 import BeltDriveCriticalSpeedAnalysis
    from ._6554 import BevelDifferentialGearCriticalSpeedAnalysis
    from ._6555 import BevelDifferentialGearMeshCriticalSpeedAnalysis
    from ._6556 import BevelDifferentialGearSetCriticalSpeedAnalysis
    from ._6557 import BevelDifferentialPlanetGearCriticalSpeedAnalysis
    from ._6558 import BevelDifferentialSunGearCriticalSpeedAnalysis
    from ._6559 import BevelGearCriticalSpeedAnalysis
    from ._6560 import BevelGearMeshCriticalSpeedAnalysis
    from ._6561 import BevelGearSetCriticalSpeedAnalysis
    from ._6562 import BoltCriticalSpeedAnalysis
    from ._6563 import BoltedJointCriticalSpeedAnalysis
    from ._6564 import ClutchConnectionCriticalSpeedAnalysis
    from ._6565 import ClutchCriticalSpeedAnalysis
    from ._6566 import ClutchHalfCriticalSpeedAnalysis
    from ._6567 import CoaxialConnectionCriticalSpeedAnalysis
    from ._6568 import ComponentCriticalSpeedAnalysis
    from ._6569 import ConceptCouplingConnectionCriticalSpeedAnalysis
    from ._6570 import ConceptCouplingCriticalSpeedAnalysis
    from ._6571 import ConceptCouplingHalfCriticalSpeedAnalysis
    from ._6572 import ConceptGearCriticalSpeedAnalysis
    from ._6573 import ConceptGearMeshCriticalSpeedAnalysis
    from ._6574 import ConceptGearSetCriticalSpeedAnalysis
    from ._6575 import ConicalGearCriticalSpeedAnalysis
    from ._6576 import ConicalGearMeshCriticalSpeedAnalysis
    from ._6577 import ConicalGearSetCriticalSpeedAnalysis
    from ._6578 import ConnectionCriticalSpeedAnalysis
    from ._6579 import ConnectorCriticalSpeedAnalysis
    from ._6580 import CouplingConnectionCriticalSpeedAnalysis
    from ._6581 import CouplingCriticalSpeedAnalysis
    from ._6582 import CouplingHalfCriticalSpeedAnalysis
    from ._6583 import CriticalSpeedAnalysis
    from ._6584 import CriticalSpeedAnalysisDrawStyle
    from ._6585 import CriticalSpeedAnalysisOptions
    from ._6586 import CVTBeltConnectionCriticalSpeedAnalysis
    from ._6587 import CVTCriticalSpeedAnalysis
    from ._6588 import CVTPulleyCriticalSpeedAnalysis
    from ._6589 import CycloidalAssemblyCriticalSpeedAnalysis
    from ._6590 import CycloidalDiscCentralBearingConnectionCriticalSpeedAnalysis
    from ._6591 import CycloidalDiscCriticalSpeedAnalysis
    from ._6592 import CycloidalDiscPlanetaryBearingConnectionCriticalSpeedAnalysis
    from ._6593 import CylindricalGearCriticalSpeedAnalysis
    from ._6594 import CylindricalGearMeshCriticalSpeedAnalysis
    from ._6595 import CylindricalGearSetCriticalSpeedAnalysis
    from ._6596 import CylindricalPlanetGearCriticalSpeedAnalysis
    from ._6597 import DatumCriticalSpeedAnalysis
    from ._6598 import ExternalCADModelCriticalSpeedAnalysis
    from ._6599 import FaceGearCriticalSpeedAnalysis
    from ._6600 import FaceGearMeshCriticalSpeedAnalysis
    from ._6601 import FaceGearSetCriticalSpeedAnalysis
    from ._6602 import FEPartCriticalSpeedAnalysis
    from ._6603 import FlexiblePinAssemblyCriticalSpeedAnalysis
    from ._6604 import GearCriticalSpeedAnalysis
    from ._6605 import GearMeshCriticalSpeedAnalysis
    from ._6606 import GearSetCriticalSpeedAnalysis
    from ._6607 import GuideDxfModelCriticalSpeedAnalysis
    from ._6608 import HypoidGearCriticalSpeedAnalysis
    from ._6609 import HypoidGearMeshCriticalSpeedAnalysis
    from ._6610 import HypoidGearSetCriticalSpeedAnalysis
    from ._6611 import InterMountableComponentConnectionCriticalSpeedAnalysis
    from ._6612 import KlingelnbergCycloPalloidConicalGearCriticalSpeedAnalysis
    from ._6613 import KlingelnbergCycloPalloidConicalGearMeshCriticalSpeedAnalysis
    from ._6614 import KlingelnbergCycloPalloidConicalGearSetCriticalSpeedAnalysis
    from ._6615 import KlingelnbergCycloPalloidHypoidGearCriticalSpeedAnalysis
    from ._6616 import KlingelnbergCycloPalloidHypoidGearMeshCriticalSpeedAnalysis
    from ._6617 import KlingelnbergCycloPalloidHypoidGearSetCriticalSpeedAnalysis
    from ._6618 import KlingelnbergCycloPalloidSpiralBevelGearCriticalSpeedAnalysis
    from ._6619 import KlingelnbergCycloPalloidSpiralBevelGearMeshCriticalSpeedAnalysis
    from ._6620 import KlingelnbergCycloPalloidSpiralBevelGearSetCriticalSpeedAnalysis
    from ._6621 import MassDiscCriticalSpeedAnalysis
    from ._6622 import MeasurementComponentCriticalSpeedAnalysis
    from ._6623 import MountableComponentCriticalSpeedAnalysis
    from ._6624 import OilSealCriticalSpeedAnalysis
    from ._6625 import PartCriticalSpeedAnalysis
    from ._6626 import PartToPartShearCouplingConnectionCriticalSpeedAnalysis
    from ._6627 import PartToPartShearCouplingCriticalSpeedAnalysis
    from ._6628 import PartToPartShearCouplingHalfCriticalSpeedAnalysis
    from ._6629 import PlanetaryConnectionCriticalSpeedAnalysis
    from ._6630 import PlanetaryGearSetCriticalSpeedAnalysis
    from ._6631 import PlanetCarrierCriticalSpeedAnalysis
    from ._6632 import PointLoadCriticalSpeedAnalysis
    from ._6633 import PowerLoadCriticalSpeedAnalysis
    from ._6634 import PulleyCriticalSpeedAnalysis
    from ._6635 import RingPinsCriticalSpeedAnalysis
    from ._6636 import RingPinsToDiscConnectionCriticalSpeedAnalysis
    from ._6637 import RollingRingAssemblyCriticalSpeedAnalysis
    from ._6638 import RollingRingConnectionCriticalSpeedAnalysis
    from ._6639 import RollingRingCriticalSpeedAnalysis
    from ._6640 import RootAssemblyCriticalSpeedAnalysis
    from ._6641 import ShaftCriticalSpeedAnalysis
    from ._6642 import ShaftHubConnectionCriticalSpeedAnalysis
    from ._6643 import ShaftToMountableComponentConnectionCriticalSpeedAnalysis
    from ._6644 import SpecialisedAssemblyCriticalSpeedAnalysis
    from ._6645 import SpiralBevelGearCriticalSpeedAnalysis
    from ._6646 import SpiralBevelGearMeshCriticalSpeedAnalysis
    from ._6647 import SpiralBevelGearSetCriticalSpeedAnalysis
    from ._6648 import SpringDamperConnectionCriticalSpeedAnalysis
    from ._6649 import SpringDamperCriticalSpeedAnalysis
    from ._6650 import SpringDamperHalfCriticalSpeedAnalysis
    from ._6651 import StraightBevelDiffGearCriticalSpeedAnalysis
    from ._6652 import StraightBevelDiffGearMeshCriticalSpeedAnalysis
    from ._6653 import StraightBevelDiffGearSetCriticalSpeedAnalysis
    from ._6654 import StraightBevelGearCriticalSpeedAnalysis
    from ._6655 import StraightBevelGearMeshCriticalSpeedAnalysis
    from ._6656 import StraightBevelGearSetCriticalSpeedAnalysis
    from ._6657 import StraightBevelPlanetGearCriticalSpeedAnalysis
    from ._6658 import StraightBevelSunGearCriticalSpeedAnalysis
    from ._6659 import SynchroniserCriticalSpeedAnalysis
    from ._6660 import SynchroniserHalfCriticalSpeedAnalysis
    from ._6661 import SynchroniserPartCriticalSpeedAnalysis
    from ._6662 import SynchroniserSleeveCriticalSpeedAnalysis
    from ._6663 import TorqueConverterConnectionCriticalSpeedAnalysis
    from ._6664 import TorqueConverterCriticalSpeedAnalysis
    from ._6665 import TorqueConverterPumpCriticalSpeedAnalysis
    from ._6666 import TorqueConverterTurbineCriticalSpeedAnalysis
    from ._6667 import UnbalancedMassCriticalSpeedAnalysis
    from ._6668 import VirtualComponentCriticalSpeedAnalysis
    from ._6669 import WormGearCriticalSpeedAnalysis
    from ._6670 import WormGearMeshCriticalSpeedAnalysis
    from ._6671 import WormGearSetCriticalSpeedAnalysis
    from ._6672 import ZerolBevelGearCriticalSpeedAnalysis
    from ._6673 import ZerolBevelGearMeshCriticalSpeedAnalysis
    from ._6674 import ZerolBevelGearSetCriticalSpeedAnalysis
else:
    import_structure = {
        "_6543": ["AbstractAssemblyCriticalSpeedAnalysis"],
        "_6544": ["AbstractShaftCriticalSpeedAnalysis"],
        "_6545": ["AbstractShaftOrHousingCriticalSpeedAnalysis"],
        "_6546": ["AbstractShaftToMountableComponentConnectionCriticalSpeedAnalysis"],
        "_6547": ["AGMAGleasonConicalGearCriticalSpeedAnalysis"],
        "_6548": ["AGMAGleasonConicalGearMeshCriticalSpeedAnalysis"],
        "_6549": ["AGMAGleasonConicalGearSetCriticalSpeedAnalysis"],
        "_6550": ["AssemblyCriticalSpeedAnalysis"],
        "_6551": ["BearingCriticalSpeedAnalysis"],
        "_6552": ["BeltConnectionCriticalSpeedAnalysis"],
        "_6553": ["BeltDriveCriticalSpeedAnalysis"],
        "_6554": ["BevelDifferentialGearCriticalSpeedAnalysis"],
        "_6555": ["BevelDifferentialGearMeshCriticalSpeedAnalysis"],
        "_6556": ["BevelDifferentialGearSetCriticalSpeedAnalysis"],
        "_6557": ["BevelDifferentialPlanetGearCriticalSpeedAnalysis"],
        "_6558": ["BevelDifferentialSunGearCriticalSpeedAnalysis"],
        "_6559": ["BevelGearCriticalSpeedAnalysis"],
        "_6560": ["BevelGearMeshCriticalSpeedAnalysis"],
        "_6561": ["BevelGearSetCriticalSpeedAnalysis"],
        "_6562": ["BoltCriticalSpeedAnalysis"],
        "_6563": ["BoltedJointCriticalSpeedAnalysis"],
        "_6564": ["ClutchConnectionCriticalSpeedAnalysis"],
        "_6565": ["ClutchCriticalSpeedAnalysis"],
        "_6566": ["ClutchHalfCriticalSpeedAnalysis"],
        "_6567": ["CoaxialConnectionCriticalSpeedAnalysis"],
        "_6568": ["ComponentCriticalSpeedAnalysis"],
        "_6569": ["ConceptCouplingConnectionCriticalSpeedAnalysis"],
        "_6570": ["ConceptCouplingCriticalSpeedAnalysis"],
        "_6571": ["ConceptCouplingHalfCriticalSpeedAnalysis"],
        "_6572": ["ConceptGearCriticalSpeedAnalysis"],
        "_6573": ["ConceptGearMeshCriticalSpeedAnalysis"],
        "_6574": ["ConceptGearSetCriticalSpeedAnalysis"],
        "_6575": ["ConicalGearCriticalSpeedAnalysis"],
        "_6576": ["ConicalGearMeshCriticalSpeedAnalysis"],
        "_6577": ["ConicalGearSetCriticalSpeedAnalysis"],
        "_6578": ["ConnectionCriticalSpeedAnalysis"],
        "_6579": ["ConnectorCriticalSpeedAnalysis"],
        "_6580": ["CouplingConnectionCriticalSpeedAnalysis"],
        "_6581": ["CouplingCriticalSpeedAnalysis"],
        "_6582": ["CouplingHalfCriticalSpeedAnalysis"],
        "_6583": ["CriticalSpeedAnalysis"],
        "_6584": ["CriticalSpeedAnalysisDrawStyle"],
        "_6585": ["CriticalSpeedAnalysisOptions"],
        "_6586": ["CVTBeltConnectionCriticalSpeedAnalysis"],
        "_6587": ["CVTCriticalSpeedAnalysis"],
        "_6588": ["CVTPulleyCriticalSpeedAnalysis"],
        "_6589": ["CycloidalAssemblyCriticalSpeedAnalysis"],
        "_6590": ["CycloidalDiscCentralBearingConnectionCriticalSpeedAnalysis"],
        "_6591": ["CycloidalDiscCriticalSpeedAnalysis"],
        "_6592": ["CycloidalDiscPlanetaryBearingConnectionCriticalSpeedAnalysis"],
        "_6593": ["CylindricalGearCriticalSpeedAnalysis"],
        "_6594": ["CylindricalGearMeshCriticalSpeedAnalysis"],
        "_6595": ["CylindricalGearSetCriticalSpeedAnalysis"],
        "_6596": ["CylindricalPlanetGearCriticalSpeedAnalysis"],
        "_6597": ["DatumCriticalSpeedAnalysis"],
        "_6598": ["ExternalCADModelCriticalSpeedAnalysis"],
        "_6599": ["FaceGearCriticalSpeedAnalysis"],
        "_6600": ["FaceGearMeshCriticalSpeedAnalysis"],
        "_6601": ["FaceGearSetCriticalSpeedAnalysis"],
        "_6602": ["FEPartCriticalSpeedAnalysis"],
        "_6603": ["FlexiblePinAssemblyCriticalSpeedAnalysis"],
        "_6604": ["GearCriticalSpeedAnalysis"],
        "_6605": ["GearMeshCriticalSpeedAnalysis"],
        "_6606": ["GearSetCriticalSpeedAnalysis"],
        "_6607": ["GuideDxfModelCriticalSpeedAnalysis"],
        "_6608": ["HypoidGearCriticalSpeedAnalysis"],
        "_6609": ["HypoidGearMeshCriticalSpeedAnalysis"],
        "_6610": ["HypoidGearSetCriticalSpeedAnalysis"],
        "_6611": ["InterMountableComponentConnectionCriticalSpeedAnalysis"],
        "_6612": ["KlingelnbergCycloPalloidConicalGearCriticalSpeedAnalysis"],
        "_6613": ["KlingelnbergCycloPalloidConicalGearMeshCriticalSpeedAnalysis"],
        "_6614": ["KlingelnbergCycloPalloidConicalGearSetCriticalSpeedAnalysis"],
        "_6615": ["KlingelnbergCycloPalloidHypoidGearCriticalSpeedAnalysis"],
        "_6616": ["KlingelnbergCycloPalloidHypoidGearMeshCriticalSpeedAnalysis"],
        "_6617": ["KlingelnbergCycloPalloidHypoidGearSetCriticalSpeedAnalysis"],
        "_6618": ["KlingelnbergCycloPalloidSpiralBevelGearCriticalSpeedAnalysis"],
        "_6619": ["KlingelnbergCycloPalloidSpiralBevelGearMeshCriticalSpeedAnalysis"],
        "_6620": ["KlingelnbergCycloPalloidSpiralBevelGearSetCriticalSpeedAnalysis"],
        "_6621": ["MassDiscCriticalSpeedAnalysis"],
        "_6622": ["MeasurementComponentCriticalSpeedAnalysis"],
        "_6623": ["MountableComponentCriticalSpeedAnalysis"],
        "_6624": ["OilSealCriticalSpeedAnalysis"],
        "_6625": ["PartCriticalSpeedAnalysis"],
        "_6626": ["PartToPartShearCouplingConnectionCriticalSpeedAnalysis"],
        "_6627": ["PartToPartShearCouplingCriticalSpeedAnalysis"],
        "_6628": ["PartToPartShearCouplingHalfCriticalSpeedAnalysis"],
        "_6629": ["PlanetaryConnectionCriticalSpeedAnalysis"],
        "_6630": ["PlanetaryGearSetCriticalSpeedAnalysis"],
        "_6631": ["PlanetCarrierCriticalSpeedAnalysis"],
        "_6632": ["PointLoadCriticalSpeedAnalysis"],
        "_6633": ["PowerLoadCriticalSpeedAnalysis"],
        "_6634": ["PulleyCriticalSpeedAnalysis"],
        "_6635": ["RingPinsCriticalSpeedAnalysis"],
        "_6636": ["RingPinsToDiscConnectionCriticalSpeedAnalysis"],
        "_6637": ["RollingRingAssemblyCriticalSpeedAnalysis"],
        "_6638": ["RollingRingConnectionCriticalSpeedAnalysis"],
        "_6639": ["RollingRingCriticalSpeedAnalysis"],
        "_6640": ["RootAssemblyCriticalSpeedAnalysis"],
        "_6641": ["ShaftCriticalSpeedAnalysis"],
        "_6642": ["ShaftHubConnectionCriticalSpeedAnalysis"],
        "_6643": ["ShaftToMountableComponentConnectionCriticalSpeedAnalysis"],
        "_6644": ["SpecialisedAssemblyCriticalSpeedAnalysis"],
        "_6645": ["SpiralBevelGearCriticalSpeedAnalysis"],
        "_6646": ["SpiralBevelGearMeshCriticalSpeedAnalysis"],
        "_6647": ["SpiralBevelGearSetCriticalSpeedAnalysis"],
        "_6648": ["SpringDamperConnectionCriticalSpeedAnalysis"],
        "_6649": ["SpringDamperCriticalSpeedAnalysis"],
        "_6650": ["SpringDamperHalfCriticalSpeedAnalysis"],
        "_6651": ["StraightBevelDiffGearCriticalSpeedAnalysis"],
        "_6652": ["StraightBevelDiffGearMeshCriticalSpeedAnalysis"],
        "_6653": ["StraightBevelDiffGearSetCriticalSpeedAnalysis"],
        "_6654": ["StraightBevelGearCriticalSpeedAnalysis"],
        "_6655": ["StraightBevelGearMeshCriticalSpeedAnalysis"],
        "_6656": ["StraightBevelGearSetCriticalSpeedAnalysis"],
        "_6657": ["StraightBevelPlanetGearCriticalSpeedAnalysis"],
        "_6658": ["StraightBevelSunGearCriticalSpeedAnalysis"],
        "_6659": ["SynchroniserCriticalSpeedAnalysis"],
        "_6660": ["SynchroniserHalfCriticalSpeedAnalysis"],
        "_6661": ["SynchroniserPartCriticalSpeedAnalysis"],
        "_6662": ["SynchroniserSleeveCriticalSpeedAnalysis"],
        "_6663": ["TorqueConverterConnectionCriticalSpeedAnalysis"],
        "_6664": ["TorqueConverterCriticalSpeedAnalysis"],
        "_6665": ["TorqueConverterPumpCriticalSpeedAnalysis"],
        "_6666": ["TorqueConverterTurbineCriticalSpeedAnalysis"],
        "_6667": ["UnbalancedMassCriticalSpeedAnalysis"],
        "_6668": ["VirtualComponentCriticalSpeedAnalysis"],
        "_6669": ["WormGearCriticalSpeedAnalysis"],
        "_6670": ["WormGearMeshCriticalSpeedAnalysis"],
        "_6671": ["WormGearSetCriticalSpeedAnalysis"],
        "_6672": ["ZerolBevelGearCriticalSpeedAnalysis"],
        "_6673": ["ZerolBevelGearMeshCriticalSpeedAnalysis"],
        "_6674": ["ZerolBevelGearSetCriticalSpeedAnalysis"],
    }

    sys.modules[__name__] = LazyImporter(
        __name__,
        globals()["__file__"],
        import_structure,
    )

__all__ = (
    "AbstractAssemblyCriticalSpeedAnalysis",
    "AbstractShaftCriticalSpeedAnalysis",
    "AbstractShaftOrHousingCriticalSpeedAnalysis",
    "AbstractShaftToMountableComponentConnectionCriticalSpeedAnalysis",
    "AGMAGleasonConicalGearCriticalSpeedAnalysis",
    "AGMAGleasonConicalGearMeshCriticalSpeedAnalysis",
    "AGMAGleasonConicalGearSetCriticalSpeedAnalysis",
    "AssemblyCriticalSpeedAnalysis",
    "BearingCriticalSpeedAnalysis",
    "BeltConnectionCriticalSpeedAnalysis",
    "BeltDriveCriticalSpeedAnalysis",
    "BevelDifferentialGearCriticalSpeedAnalysis",
    "BevelDifferentialGearMeshCriticalSpeedAnalysis",
    "BevelDifferentialGearSetCriticalSpeedAnalysis",
    "BevelDifferentialPlanetGearCriticalSpeedAnalysis",
    "BevelDifferentialSunGearCriticalSpeedAnalysis",
    "BevelGearCriticalSpeedAnalysis",
    "BevelGearMeshCriticalSpeedAnalysis",
    "BevelGearSetCriticalSpeedAnalysis",
    "BoltCriticalSpeedAnalysis",
    "BoltedJointCriticalSpeedAnalysis",
    "ClutchConnectionCriticalSpeedAnalysis",
    "ClutchCriticalSpeedAnalysis",
    "ClutchHalfCriticalSpeedAnalysis",
    "CoaxialConnectionCriticalSpeedAnalysis",
    "ComponentCriticalSpeedAnalysis",
    "ConceptCouplingConnectionCriticalSpeedAnalysis",
    "ConceptCouplingCriticalSpeedAnalysis",
    "ConceptCouplingHalfCriticalSpeedAnalysis",
    "ConceptGearCriticalSpeedAnalysis",
    "ConceptGearMeshCriticalSpeedAnalysis",
    "ConceptGearSetCriticalSpeedAnalysis",
    "ConicalGearCriticalSpeedAnalysis",
    "ConicalGearMeshCriticalSpeedAnalysis",
    "ConicalGearSetCriticalSpeedAnalysis",
    "ConnectionCriticalSpeedAnalysis",
    "ConnectorCriticalSpeedAnalysis",
    "CouplingConnectionCriticalSpeedAnalysis",
    "CouplingCriticalSpeedAnalysis",
    "CouplingHalfCriticalSpeedAnalysis",
    "CriticalSpeedAnalysis",
    "CriticalSpeedAnalysisDrawStyle",
    "CriticalSpeedAnalysisOptions",
    "CVTBeltConnectionCriticalSpeedAnalysis",
    "CVTCriticalSpeedAnalysis",
    "CVTPulleyCriticalSpeedAnalysis",
    "CycloidalAssemblyCriticalSpeedAnalysis",
    "CycloidalDiscCentralBearingConnectionCriticalSpeedAnalysis",
    "CycloidalDiscCriticalSpeedAnalysis",
    "CycloidalDiscPlanetaryBearingConnectionCriticalSpeedAnalysis",
    "CylindricalGearCriticalSpeedAnalysis",
    "CylindricalGearMeshCriticalSpeedAnalysis",
    "CylindricalGearSetCriticalSpeedAnalysis",
    "CylindricalPlanetGearCriticalSpeedAnalysis",
    "DatumCriticalSpeedAnalysis",
    "ExternalCADModelCriticalSpeedAnalysis",
    "FaceGearCriticalSpeedAnalysis",
    "FaceGearMeshCriticalSpeedAnalysis",
    "FaceGearSetCriticalSpeedAnalysis",
    "FEPartCriticalSpeedAnalysis",
    "FlexiblePinAssemblyCriticalSpeedAnalysis",
    "GearCriticalSpeedAnalysis",
    "GearMeshCriticalSpeedAnalysis",
    "GearSetCriticalSpeedAnalysis",
    "GuideDxfModelCriticalSpeedAnalysis",
    "HypoidGearCriticalSpeedAnalysis",
    "HypoidGearMeshCriticalSpeedAnalysis",
    "HypoidGearSetCriticalSpeedAnalysis",
    "InterMountableComponentConnectionCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidConicalGearCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidConicalGearMeshCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidConicalGearSetCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidHypoidGearCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMeshCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidHypoidGearSetCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCriticalSpeedAnalysis",
    "MassDiscCriticalSpeedAnalysis",
    "MeasurementComponentCriticalSpeedAnalysis",
    "MountableComponentCriticalSpeedAnalysis",
    "OilSealCriticalSpeedAnalysis",
    "PartCriticalSpeedAnalysis",
    "PartToPartShearCouplingConnectionCriticalSpeedAnalysis",
    "PartToPartShearCouplingCriticalSpeedAnalysis",
    "PartToPartShearCouplingHalfCriticalSpeedAnalysis",
    "PlanetaryConnectionCriticalSpeedAnalysis",
    "PlanetaryGearSetCriticalSpeedAnalysis",
    "PlanetCarrierCriticalSpeedAnalysis",
    "PointLoadCriticalSpeedAnalysis",
    "PowerLoadCriticalSpeedAnalysis",
    "PulleyCriticalSpeedAnalysis",
    "RingPinsCriticalSpeedAnalysis",
    "RingPinsToDiscConnectionCriticalSpeedAnalysis",
    "RollingRingAssemblyCriticalSpeedAnalysis",
    "RollingRingConnectionCriticalSpeedAnalysis",
    "RollingRingCriticalSpeedAnalysis",
    "RootAssemblyCriticalSpeedAnalysis",
    "ShaftCriticalSpeedAnalysis",
    "ShaftHubConnectionCriticalSpeedAnalysis",
    "ShaftToMountableComponentConnectionCriticalSpeedAnalysis",
    "SpecialisedAssemblyCriticalSpeedAnalysis",
    "SpiralBevelGearCriticalSpeedAnalysis",
    "SpiralBevelGearMeshCriticalSpeedAnalysis",
    "SpiralBevelGearSetCriticalSpeedAnalysis",
    "SpringDamperConnectionCriticalSpeedAnalysis",
    "SpringDamperCriticalSpeedAnalysis",
    "SpringDamperHalfCriticalSpeedAnalysis",
    "StraightBevelDiffGearCriticalSpeedAnalysis",
    "StraightBevelDiffGearMeshCriticalSpeedAnalysis",
    "StraightBevelDiffGearSetCriticalSpeedAnalysis",
    "StraightBevelGearCriticalSpeedAnalysis",
    "StraightBevelGearMeshCriticalSpeedAnalysis",
    "StraightBevelGearSetCriticalSpeedAnalysis",
    "StraightBevelPlanetGearCriticalSpeedAnalysis",
    "StraightBevelSunGearCriticalSpeedAnalysis",
    "SynchroniserCriticalSpeedAnalysis",
    "SynchroniserHalfCriticalSpeedAnalysis",
    "SynchroniserPartCriticalSpeedAnalysis",
    "SynchroniserSleeveCriticalSpeedAnalysis",
    "TorqueConverterConnectionCriticalSpeedAnalysis",
    "TorqueConverterCriticalSpeedAnalysis",
    "TorqueConverterPumpCriticalSpeedAnalysis",
    "TorqueConverterTurbineCriticalSpeedAnalysis",
    "UnbalancedMassCriticalSpeedAnalysis",
    "VirtualComponentCriticalSpeedAnalysis",
    "WormGearCriticalSpeedAnalysis",
    "WormGearMeshCriticalSpeedAnalysis",
    "WormGearSetCriticalSpeedAnalysis",
    "ZerolBevelGearCriticalSpeedAnalysis",
    "ZerolBevelGearMeshCriticalSpeedAnalysis",
    "ZerolBevelGearSetCriticalSpeedAnalysis",
)



"""CutterShapeDefinition"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List

from mastapy._internal import constructor, conversion
from mastapy import _0
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_CUTTER_SHAPE_DEFINITION = python_net_import(
    "SMT.MastaAPI.Gears.Manufacturing.Cylindrical.Cutters.Tangibles",
    "CutterShapeDefinition",
)

if TYPE_CHECKING:
    from mastapy.gears.manufacturing.cylindrical.cutters import _713
    from mastapy.gears.manufacturing.cylindrical.cutters.tangibles import (
        _729,
        _724,
        _725,
        _726,
        _727,
        _728,
        _730,
    )


__docformat__ = "restructuredtext en"
__all__ = ("CutterShapeDefinition",)


Self = TypeVar("Self", bound="CutterShapeDefinition")


class CutterShapeDefinition(_0.APIBase):
    """CutterShapeDefinition

    This is a mastapy class.
    """

    TYPE = _CUTTER_SHAPE_DEFINITION
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_CutterShapeDefinition")

    class _Cast_CutterShapeDefinition:
        """Special nested class for casting CutterShapeDefinition to subclasses."""

        def __init__(
            self: "CutterShapeDefinition._Cast_CutterShapeDefinition",
            parent: "CutterShapeDefinition",
        ):
            self._parent = parent

        @property
        def cylindrical_gear_formed_wheel_grinder_tangible(
            self: "CutterShapeDefinition._Cast_CutterShapeDefinition",
        ) -> "_724.CylindricalGearFormedWheelGrinderTangible":
            from mastapy.gears.manufacturing.cylindrical.cutters.tangibles import _724

            return self._parent._cast(_724.CylindricalGearFormedWheelGrinderTangible)

        @property
        def cylindrical_gear_hob_shape(
            self: "CutterShapeDefinition._Cast_CutterShapeDefinition",
        ) -> "_725.CylindricalGearHobShape":
            from mastapy.gears.manufacturing.cylindrical.cutters.tangibles import _725

            return self._parent._cast(_725.CylindricalGearHobShape)

        @property
        def cylindrical_gear_shaper_tangible(
            self: "CutterShapeDefinition._Cast_CutterShapeDefinition",
        ) -> "_726.CylindricalGearShaperTangible":
            from mastapy.gears.manufacturing.cylindrical.cutters.tangibles import _726

            return self._parent._cast(_726.CylindricalGearShaperTangible)

        @property
        def cylindrical_gear_shaver_tangible(
            self: "CutterShapeDefinition._Cast_CutterShapeDefinition",
        ) -> "_727.CylindricalGearShaverTangible":
            from mastapy.gears.manufacturing.cylindrical.cutters.tangibles import _727

            return self._parent._cast(_727.CylindricalGearShaverTangible)

        @property
        def cylindrical_gear_worm_grinder_shape(
            self: "CutterShapeDefinition._Cast_CutterShapeDefinition",
        ) -> "_728.CylindricalGearWormGrinderShape":
            from mastapy.gears.manufacturing.cylindrical.cutters.tangibles import _728

            return self._parent._cast(_728.CylindricalGearWormGrinderShape)

        @property
        def rack_shape(
            self: "CutterShapeDefinition._Cast_CutterShapeDefinition",
        ) -> "_730.RackShape":
            from mastapy.gears.manufacturing.cylindrical.cutters.tangibles import _730

            return self._parent._cast(_730.RackShape)

        @property
        def cutter_shape_definition(
            self: "CutterShapeDefinition._Cast_CutterShapeDefinition",
        ) -> "CutterShapeDefinition":
            return self._parent

        def __getattr__(
            self: "CutterShapeDefinition._Cast_CutterShapeDefinition", name: str
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "CutterShapeDefinition.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def normal_module(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NormalModule

        if temp is None:
            return 0.0

        return temp

    @property
    def normal_pitch(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NormalPitch

        if temp is None:
            return 0.0

        return temp

    @property
    def normal_pressure_angle(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NormalPressureAngle

        if temp is None:
            return 0.0

        return temp

    @property
    def design(self: Self) -> "_713.CylindricalGearRealCutterDesign":
        """mastapy.gears.manufacturing.cylindrical.cutters.CylindricalGearRealCutterDesign

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Design

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def fillet_points(self: Self) -> "List[_729.NamedPoint]":
        """List[mastapy.gears.manufacturing.cylindrical.cutters.tangibles.NamedPoint]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FilletPoints

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def main_blade_points(self: Self) -> "List[_729.NamedPoint]":
        """List[mastapy.gears.manufacturing.cylindrical.cutters.tangibles.NamedPoint]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MainBladePoints

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: Self) -> "CutterShapeDefinition._Cast_CutterShapeDefinition":
        return self._Cast_CutterShapeDefinition(self)



"""DynamicForceAnalysis"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List

from mastapy._internal import constructor, conversion
from mastapy.electric_machines.load_cases_and_analyses import _1351
from mastapy.electric_machines.results import _1338
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_DYNAMIC_FORCE_ANALYSIS = python_net_import(
    "SMT.MastaAPI.ElectricMachines.LoadCasesAndAnalyses", "DynamicForceAnalysis"
)

if TYPE_CHECKING:
    from mastapy.electric_machines.load_cases_and_analyses import _1345, _1355
    from mastapy.electric_machines.results import _1320


__docformat__ = "restructuredtext en"
__all__ = ("DynamicForceAnalysis",)


Self = TypeVar("Self", bound="DynamicForceAnalysis")


class DynamicForceAnalysis(
    _1351.ElectricMachineAnalysis, _1338.IHaveDynamicForceResults
):
    """DynamicForceAnalysis

    This is a mastapy class.
    """

    TYPE = _DYNAMIC_FORCE_ANALYSIS
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_DynamicForceAnalysis")

    class _Cast_DynamicForceAnalysis:
        """Special nested class for casting DynamicForceAnalysis to subclasses."""

        def __init__(
            self: "DynamicForceAnalysis._Cast_DynamicForceAnalysis",
            parent: "DynamicForceAnalysis",
        ):
            self._parent = parent

        @property
        def electric_machine_analysis(
            self: "DynamicForceAnalysis._Cast_DynamicForceAnalysis",
        ) -> "_1351.ElectricMachineAnalysis":
            return self._parent._cast(_1351.ElectricMachineAnalysis)

        @property
        def dynamic_force_analysis(
            self: "DynamicForceAnalysis._Cast_DynamicForceAnalysis",
        ) -> "DynamicForceAnalysis":
            return self._parent

        def __getattr__(
            self: "DynamicForceAnalysis._Cast_DynamicForceAnalysis", name: str
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "DynamicForceAnalysis.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def number_of_steps_per_operating_point(self: Self) -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfStepsPerOperatingPoint

        if temp is None:
            return 0

        return temp

    @property
    def load_case(self: Self) -> "_1345.BasicDynamicForceLoadCase":
        """mastapy.electric_machines.load_cases_and_analyses.BasicDynamicForceLoadCase

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LoadCase

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def results(self: Self) -> "_1320.DynamicForceResults":
        """mastapy.electric_machines.results.DynamicForceResults

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Results

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def single_operating_point_analyses(
        self: Self,
    ) -> "List[_1355.ElectricMachineFEAnalysis]":
        """List[mastapy.electric_machines.load_cases_and_analyses.ElectricMachineFEAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SingleOperatingPointAnalyses

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: Self) -> "DynamicForceAnalysis._Cast_DynamicForceAnalysis":
        return self._Cast_DynamicForceAnalysis(self)



"""BeltDrive"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal import constructor, conversion
from mastapy.system_model.part_model import _2476
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_BELT_DRIVE = python_net_import(
    "SMT.MastaAPI.SystemModel.PartModel.Couplings", "BeltDrive"
)

if TYPE_CHECKING:
    from mastapy.system_model.part_model.couplings import _2577, _2590, _2586
    from mastapy.system_model.connections_and_sockets import _2268
    from mastapy.system_model.part_model import _2434, _2468
    from mastapy.system_model import _2203


__docformat__ = "restructuredtext en"
__all__ = ("BeltDrive",)


Self = TypeVar("Self", bound="BeltDrive")


class BeltDrive(_2476.SpecialisedAssembly):
    """BeltDrive

    This is a mastapy class.
    """

    TYPE = _BELT_DRIVE
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_BeltDrive")

    class _Cast_BeltDrive:
        """Special nested class for casting BeltDrive to subclasses."""

        def __init__(self: "BeltDrive._Cast_BeltDrive", parent: "BeltDrive"):
            self._parent = parent

        @property
        def specialised_assembly(
            self: "BeltDrive._Cast_BeltDrive",
        ) -> "_2476.SpecialisedAssembly":
            return self._parent._cast(_2476.SpecialisedAssembly)

        @property
        def abstract_assembly(
            self: "BeltDrive._Cast_BeltDrive",
        ) -> "_2434.AbstractAssembly":
            from mastapy.system_model.part_model import _2434

            return self._parent._cast(_2434.AbstractAssembly)

        @property
        def part(self: "BeltDrive._Cast_BeltDrive") -> "_2468.Part":
            from mastapy.system_model.part_model import _2468

            return self._parent._cast(_2468.Part)

        @property
        def design_entity(self: "BeltDrive._Cast_BeltDrive") -> "_2203.DesignEntity":
            from mastapy.system_model import _2203

            return self._parent._cast(_2203.DesignEntity)

        @property
        def cvt(self: "BeltDrive._Cast_BeltDrive") -> "_2586.CVT":
            from mastapy.system_model.part_model.couplings import _2586

            return self._parent._cast(_2586.CVT)

        @property
        def belt_drive(self: "BeltDrive._Cast_BeltDrive") -> "BeltDrive":
            return self._parent

        def __getattr__(self: "BeltDrive._Cast_BeltDrive", name: str):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "BeltDrive.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def belt_length(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BeltLength

        if temp is None:
            return 0.0

        return temp

    @property
    def belt_mass(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BeltMass

        if temp is None:
            return 0.0

        return temp

    @property
    def belt_mass_per_unit_length(self: Self) -> "float":
        """float"""
        temp = self.wrapped.BeltMassPerUnitLength

        if temp is None:
            return 0.0

        return temp

    @belt_mass_per_unit_length.setter
    @enforce_parameter_types
    def belt_mass_per_unit_length(self: Self, value: "float"):
        self.wrapped.BeltMassPerUnitLength = float(value) if value is not None else 0.0

    @property
    def pre_tension(self: Self) -> "float":
        """float"""
        temp = self.wrapped.PreTension

        if temp is None:
            return 0.0

        return temp

    @pre_tension.setter
    @enforce_parameter_types
    def pre_tension(self: Self, value: "float"):
        self.wrapped.PreTension = float(value) if value is not None else 0.0

    @property
    def specify_stiffness_for_unit_length(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.SpecifyStiffnessForUnitLength

        if temp is None:
            return False

        return temp

    @specify_stiffness_for_unit_length.setter
    @enforce_parameter_types
    def specify_stiffness_for_unit_length(self: Self, value: "bool"):
        self.wrapped.SpecifyStiffnessForUnitLength = (
            bool(value) if value is not None else False
        )

    @property
    def stiffness(self: Self) -> "float":
        """float"""
        temp = self.wrapped.Stiffness

        if temp is None:
            return 0.0

        return temp

    @stiffness.setter
    @enforce_parameter_types
    def stiffness(self: Self, value: "float"):
        self.wrapped.Stiffness = float(value) if value is not None else 0.0

    @property
    def stiffness_for_unit_length(self: Self) -> "float":
        """float"""
        temp = self.wrapped.StiffnessForUnitLength

        if temp is None:
            return 0.0

        return temp

    @stiffness_for_unit_length.setter
    @enforce_parameter_types
    def stiffness_for_unit_length(self: Self, value: "float"):
        self.wrapped.StiffnessForUnitLength = float(value) if value is not None else 0.0

    @property
    def type_of_belt(self: Self) -> "_2577.BeltDriveType":
        """mastapy.system_model.part_model.couplings.BeltDriveType"""
        temp = self.wrapped.TypeOfBelt

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.SystemModel.PartModel.Couplings.BeltDriveType"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy.system_model.part_model.couplings._2577", "BeltDriveType"
        )(value)

    @type_of_belt.setter
    @enforce_parameter_types
    def type_of_belt(self: Self, value: "_2577.BeltDriveType"):
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.SystemModel.PartModel.Couplings.BeltDriveType"
        )
        self.wrapped.TypeOfBelt = value

    @property
    def belt_connections(self: Self) -> "List[_2268.BeltConnection]":
        """List[mastapy.system_model.connections_and_sockets.BeltConnection]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BeltConnections

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def pulleys(self: Self) -> "List[_2590.Pulley]":
        """List[mastapy.system_model.part_model.couplings.Pulley]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Pulleys

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: Self) -> "BeltDrive._Cast_BeltDrive":
        return self._Cast_BeltDrive(self)



"""SAESplineJointDesign"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal import constructor, conversion
from mastapy.detailed_rigid_connectors.splines import _1419
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_SAE_SPLINE_JOINT_DESIGN = python_net_import(
    "SMT.MastaAPI.DetailedRigidConnectors.Splines", "SAESplineJointDesign"
)

if TYPE_CHECKING:
    from mastapy.detailed_rigid_connectors.splines import _1394, _1414
    from mastapy.detailed_rigid_connectors import _1386


__docformat__ = "restructuredtext en"
__all__ = ("SAESplineJointDesign",)


Self = TypeVar("Self", bound="SAESplineJointDesign")


class SAESplineJointDesign(_1419.StandardSplineJointDesign):
    """SAESplineJointDesign

    This is a mastapy class.
    """

    TYPE = _SAE_SPLINE_JOINT_DESIGN
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_SAESplineJointDesign")

    class _Cast_SAESplineJointDesign:
        """Special nested class for casting SAESplineJointDesign to subclasses."""

        def __init__(
            self: "SAESplineJointDesign._Cast_SAESplineJointDesign",
            parent: "SAESplineJointDesign",
        ):
            self._parent = parent

        @property
        def standard_spline_joint_design(
            self: "SAESplineJointDesign._Cast_SAESplineJointDesign",
        ) -> "_1419.StandardSplineJointDesign":
            return self._parent._cast(_1419.StandardSplineJointDesign)

        @property
        def spline_joint_design(
            self: "SAESplineJointDesign._Cast_SAESplineJointDesign",
        ) -> "_1414.SplineJointDesign":
            from mastapy.detailed_rigid_connectors.splines import _1414

            return self._parent._cast(_1414.SplineJointDesign)

        @property
        def detailed_rigid_connector_design(
            self: "SAESplineJointDesign._Cast_SAESplineJointDesign",
        ) -> "_1386.DetailedRigidConnectorDesign":
            from mastapy.detailed_rigid_connectors import _1386

            return self._parent._cast(_1386.DetailedRigidConnectorDesign)

        @property
        def sae_spline_joint_design(
            self: "SAESplineJointDesign._Cast_SAESplineJointDesign",
        ) -> "SAESplineJointDesign":
            return self._parent

        def __getattr__(
            self: "SAESplineJointDesign._Cast_SAESplineJointDesign", name: str
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "SAESplineJointDesign.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def fit_type(self: Self) -> "_1394.FitTypes":
        """mastapy.detailed_rigid_connectors.splines.FitTypes"""
        temp = self.wrapped.FitType

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.DetailedRigidConnectors.Splines.FitTypes"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy.detailed_rigid_connectors.splines._1394", "FitTypes"
        )(value)

    @fit_type.setter
    @enforce_parameter_types
    def fit_type(self: Self, value: "_1394.FitTypes"):
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.DetailedRigidConnectors.Splines.FitTypes"
        )
        self.wrapped.FitType = value

    @property
    def form_clearance(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FormClearance

        if temp is None:
            return 0.0

        return temp

    @property
    def maximum_effective_clearance(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaximumEffectiveClearance

        if temp is None:
            return 0.0

        return temp

    @property
    def maximum_tip_chamfer(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaximumTipChamfer

        if temp is None:
            return 0.0

        return temp

    @property
    def minimum_effective_clearance(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MinimumEffectiveClearance

        if temp is None:
            return 0.0

        return temp

    @property
    def minimum_tip_chamfer(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MinimumTipChamfer

        if temp is None:
            return 0.0

        return temp

    @property
    def number_of_teeth(self: Self) -> "int":
        """int"""
        temp = self.wrapped.NumberOfTeeth

        if temp is None:
            return 0

        return temp

    @number_of_teeth.setter
    @enforce_parameter_types
    def number_of_teeth(self: Self, value: "int"):
        self.wrapped.NumberOfTeeth = int(value) if value is not None else 0

    @property
    def use_internal_half_minimum_minor_diameter_for_external_half_form_diameter_calculation(
        self: Self,
    ) -> "bool":
        """bool"""
        temp = (
            self.wrapped.UseInternalHalfMinimumMinorDiameterForExternalHalfFormDiameterCalculation
        )

        if temp is None:
            return False

        return temp

    @use_internal_half_minimum_minor_diameter_for_external_half_form_diameter_calculation.setter
    @enforce_parameter_types
    def use_internal_half_minimum_minor_diameter_for_external_half_form_diameter_calculation(
        self: Self, value: "bool"
    ):
        self.wrapped.UseInternalHalfMinimumMinorDiameterForExternalHalfFormDiameterCalculation = (
            bool(value) if value is not None else False
        )

    @property
    def use_saeb921b_1996(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.UseSAEB921b1996

        if temp is None:
            return False

        return temp

    @use_saeb921b_1996.setter
    @enforce_parameter_types
    def use_saeb921b_1996(self: Self, value: "bool"):
        self.wrapped.UseSAEB921b1996 = bool(value) if value is not None else False

    @property
    def cast_to(self: Self) -> "SAESplineJointDesign._Cast_SAESplineJointDesign":
        return self._Cast_SAESplineJointDesign(self)



"""InteriorPermanentMagnetMachine"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy._internal import constructor
from mastapy.electric_machines import _1285
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_INTERIOR_PERMANENT_MAGNET_MACHINE = python_net_import(
    "SMT.MastaAPI.ElectricMachines", "InteriorPermanentMagnetMachine"
)

if TYPE_CHECKING:
    from mastapy.electric_machines import _1274, _1261


__docformat__ = "restructuredtext en"
__all__ = ("InteriorPermanentMagnetMachine",)


Self = TypeVar("Self", bound="InteriorPermanentMagnetMachine")


class InteriorPermanentMagnetMachine(_1285.NonCADElectricMachineDetail):
    """InteriorPermanentMagnetMachine

    This is a mastapy class.
    """

    TYPE = _INTERIOR_PERMANENT_MAGNET_MACHINE
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_InteriorPermanentMagnetMachine")

    class _Cast_InteriorPermanentMagnetMachine:
        """Special nested class for casting InteriorPermanentMagnetMachine to subclasses."""

        def __init__(
            self: "InteriorPermanentMagnetMachine._Cast_InteriorPermanentMagnetMachine",
            parent: "InteriorPermanentMagnetMachine",
        ):
            self._parent = parent

        @property
        def non_cad_electric_machine_detail(
            self: "InteriorPermanentMagnetMachine._Cast_InteriorPermanentMagnetMachine",
        ) -> "_1285.NonCADElectricMachineDetail":
            return self._parent._cast(_1285.NonCADElectricMachineDetail)

        @property
        def electric_machine_detail(
            self: "InteriorPermanentMagnetMachine._Cast_InteriorPermanentMagnetMachine",
        ) -> "_1261.ElectricMachineDetail":
            from mastapy.electric_machines import _1261

            return self._parent._cast(_1261.ElectricMachineDetail)

        @property
        def interior_permanent_magnet_machine(
            self: "InteriorPermanentMagnetMachine._Cast_InteriorPermanentMagnetMachine",
        ) -> "InteriorPermanentMagnetMachine":
            return self._parent

        def __getattr__(
            self: "InteriorPermanentMagnetMachine._Cast_InteriorPermanentMagnetMachine",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "InteriorPermanentMagnetMachine.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def rotor(
        self: Self,
    ) -> "_1274.InteriorPermanentMagnetAndSynchronousReluctanceRotor":
        """mastapy.electric_machines.InteriorPermanentMagnetAndSynchronousReluctanceRotor

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Rotor

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(
        self: Self,
    ) -> "InteriorPermanentMagnetMachine._Cast_InteriorPermanentMagnetMachine":
        return self._Cast_InteriorPermanentMagnetMachine(self)



"""Eccentricity"""

from __future__ import annotations

from typing import TypeVar

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy.utility import _1586
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_ECCENTRICITY = python_net_import("SMT.MastaAPI.ElectricMachines", "Eccentricity")


__docformat__ = "restructuredtext en"
__all__ = ("Eccentricity",)


Self = TypeVar("Self", bound="Eccentricity")


class Eccentricity(_1586.IndependentReportablePropertiesBase["Eccentricity"]):
    """Eccentricity

    This is a mastapy class.
    """

    TYPE = _ECCENTRICITY
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_Eccentricity")

    class _Cast_Eccentricity:
        """Special nested class for casting Eccentricity to subclasses."""

        def __init__(self: "Eccentricity._Cast_Eccentricity", parent: "Eccentricity"):
            self._parent = parent

        @property
        def independent_reportable_properties_base(
            self: "Eccentricity._Cast_Eccentricity",
        ) -> "_1586.IndependentReportablePropertiesBase":
            pass

            return self._parent._cast(_1586.IndependentReportablePropertiesBase)

        @property
        def eccentricity(self: "Eccentricity._Cast_Eccentricity") -> "Eccentricity":
            return self._parent

        def __getattr__(self: "Eccentricity._Cast_Eccentricity", name: str):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "Eccentricity.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def dynamic_x(self: Self) -> "float":
        """float"""
        temp = self.wrapped.DynamicX

        if temp is None:
            return 0.0

        return temp

    @dynamic_x.setter
    @enforce_parameter_types
    def dynamic_x(self: Self, value: "float"):
        self.wrapped.DynamicX = float(value) if value is not None else 0.0

    @property
    def dynamic_y(self: Self) -> "float":
        """float"""
        temp = self.wrapped.DynamicY

        if temp is None:
            return 0.0

        return temp

    @dynamic_y.setter
    @enforce_parameter_types
    def dynamic_y(self: Self, value: "float"):
        self.wrapped.DynamicY = float(value) if value is not None else 0.0

    @property
    def static_x(self: Self) -> "float":
        """float"""
        temp = self.wrapped.StaticX

        if temp is None:
            return 0.0

        return temp

    @static_x.setter
    @enforce_parameter_types
    def static_x(self: Self, value: "float"):
        self.wrapped.StaticX = float(value) if value is not None else 0.0

    @property
    def static_y(self: Self) -> "float":
        """float"""
        temp = self.wrapped.StaticY

        if temp is None:
            return 0.0

        return temp

    @static_y.setter
    @enforce_parameter_types
    def static_y(self: Self, value: "float"):
        self.wrapped.StaticY = float(value) if value is not None else 0.0

    @property
    def cast_to(self: Self) -> "Eccentricity._Cast_Eccentricity":
        return self._Cast_Eccentricity(self)



"""RaceBearingFESystemDeflection"""

from __future__ import annotations

from typing import TypeVar

from mastapy import _0
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_RACE_BEARING_FE_SYSTEM_DEFLECTION = python_net_import(
    "SMT.MastaAPI.SystemModel.FE", "RaceBearingFESystemDeflection"
)


__docformat__ = "restructuredtext en"
__all__ = ("RaceBearingFESystemDeflection",)


Self = TypeVar("Self", bound="RaceBearingFESystemDeflection")


class RaceBearingFESystemDeflection(_0.APIBase):
    """RaceBearingFESystemDeflection

    This is a mastapy class.
    """

    TYPE = _RACE_BEARING_FE_SYSTEM_DEFLECTION
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_RaceBearingFESystemDeflection")

    class _Cast_RaceBearingFESystemDeflection:
        """Special nested class for casting RaceBearingFESystemDeflection to subclasses."""

        def __init__(
            self: "RaceBearingFESystemDeflection._Cast_RaceBearingFESystemDeflection",
            parent: "RaceBearingFESystemDeflection",
        ):
            self._parent = parent

        @property
        def race_bearing_fe_system_deflection(
            self: "RaceBearingFESystemDeflection._Cast_RaceBearingFESystemDeflection",
        ) -> "RaceBearingFESystemDeflection":
            return self._parent

        def __getattr__(
            self: "RaceBearingFESystemDeflection._Cast_RaceBearingFESystemDeflection",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "RaceBearingFESystemDeflection.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def name(self: Self) -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Name

        if temp is None:
            return ""

        return temp

    @property
    def cast_to(
        self: Self,
    ) -> "RaceBearingFESystemDeflection._Cast_RaceBearingFESystemDeflection":
        return self._Cast_RaceBearingFESystemDeflection(self)



"""MultiNodeFELink"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy.system_model.fe.links import _2418
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_MULTI_NODE_FE_LINK = python_net_import(
    "SMT.MastaAPI.SystemModel.FE.Links", "MultiNodeFELink"
)

if TYPE_CHECKING:
    from mastapy.system_model.fe.links import (
        _2419,
        _2421,
        _2422,
        _2423,
        _2424,
        _2426,
        _2427,
        _2428,
        _2429,
        _2430,
        _2431,
    )


__docformat__ = "restructuredtext en"
__all__ = ("MultiNodeFELink",)


Self = TypeVar("Self", bound="MultiNodeFELink")


class MultiNodeFELink(_2418.FELink):
    """MultiNodeFELink

    This is a mastapy class.
    """

    TYPE = _MULTI_NODE_FE_LINK
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_MultiNodeFELink")

    class _Cast_MultiNodeFELink:
        """Special nested class for casting MultiNodeFELink to subclasses."""

        def __init__(
            self: "MultiNodeFELink._Cast_MultiNodeFELink", parent: "MultiNodeFELink"
        ):
            self._parent = parent

        @property
        def fe_link(self: "MultiNodeFELink._Cast_MultiNodeFELink") -> "_2418.FELink":
            return self._parent._cast(_2418.FELink)

        @property
        def electric_machine_stator_fe_link(
            self: "MultiNodeFELink._Cast_MultiNodeFELink",
        ) -> "_2419.ElectricMachineStatorFELink":
            from mastapy.system_model.fe.links import _2419

            return self._parent._cast(_2419.ElectricMachineStatorFELink)

        @property
        def gear_mesh_fe_link(
            self: "MultiNodeFELink._Cast_MultiNodeFELink",
        ) -> "_2421.GearMeshFELink":
            from mastapy.system_model.fe.links import _2421

            return self._parent._cast(_2421.GearMeshFELink)

        @property
        def gear_with_duplicated_meshes_fe_link(
            self: "MultiNodeFELink._Cast_MultiNodeFELink",
        ) -> "_2422.GearWithDuplicatedMeshesFELink":
            from mastapy.system_model.fe.links import _2422

            return self._parent._cast(_2422.GearWithDuplicatedMeshesFELink)

        @property
        def multi_angle_connection_fe_link(
            self: "MultiNodeFELink._Cast_MultiNodeFELink",
        ) -> "_2423.MultiAngleConnectionFELink":
            from mastapy.system_model.fe.links import _2423

            return self._parent._cast(_2423.MultiAngleConnectionFELink)

        @property
        def multi_node_connector_fe_link(
            self: "MultiNodeFELink._Cast_MultiNodeFELink",
        ) -> "_2424.MultiNodeConnectorFELink":
            from mastapy.system_model.fe.links import _2424

            return self._parent._cast(_2424.MultiNodeConnectorFELink)

        @property
        def planetary_connector_multi_node_fe_link(
            self: "MultiNodeFELink._Cast_MultiNodeFELink",
        ) -> "_2426.PlanetaryConnectorMultiNodeFELink":
            from mastapy.system_model.fe.links import _2426

            return self._parent._cast(_2426.PlanetaryConnectorMultiNodeFELink)

        @property
        def planet_based_fe_link(
            self: "MultiNodeFELink._Cast_MultiNodeFELink",
        ) -> "_2427.PlanetBasedFELink":
            from mastapy.system_model.fe.links import _2427

            return self._parent._cast(_2427.PlanetBasedFELink)

        @property
        def planet_carrier_fe_link(
            self: "MultiNodeFELink._Cast_MultiNodeFELink",
        ) -> "_2428.PlanetCarrierFELink":
            from mastapy.system_model.fe.links import _2428

            return self._parent._cast(_2428.PlanetCarrierFELink)

        @property
        def point_load_fe_link(
            self: "MultiNodeFELink._Cast_MultiNodeFELink",
        ) -> "_2429.PointLoadFELink":
            from mastapy.system_model.fe.links import _2429

            return self._parent._cast(_2429.PointLoadFELink)

        @property
        def rolling_ring_connection_fe_link(
            self: "MultiNodeFELink._Cast_MultiNodeFELink",
        ) -> "_2430.RollingRingConnectionFELink":
            from mastapy.system_model.fe.links import _2430

            return self._parent._cast(_2430.RollingRingConnectionFELink)

        @property
        def shaft_hub_connection_fe_link(
            self: "MultiNodeFELink._Cast_MultiNodeFELink",
        ) -> "_2431.ShaftHubConnectionFELink":
            from mastapy.system_model.fe.links import _2431

            return self._parent._cast(_2431.ShaftHubConnectionFELink)

        @property
        def multi_node_fe_link(
            self: "MultiNodeFELink._Cast_MultiNodeFELink",
        ) -> "MultiNodeFELink":
            return self._parent

        def __getattr__(self: "MultiNodeFELink._Cast_MultiNodeFELink", name: str):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "MultiNodeFELink.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def cast_to(self: Self) -> "MultiNodeFELink._Cast_MultiNodeFELink":
        return self._Cast_MultiNodeFELink(self)



"""AbstractVaryingInputComponent"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal import constructor, enum_with_selected_value_runtime, conversion
from mastapy._internal.implicit import enum_with_selected_value
from mastapy.nodal_analysis import _91
from mastapy.nodal_analysis.varying_input_components import _98
from mastapy import _0
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_ABSTRACT_VARYING_INPUT_COMPONENT = python_net_import(
    "SMT.MastaAPI.NodalAnalysis.VaryingInputComponents", "AbstractVaryingInputComponent"
)

if TYPE_CHECKING:
    from mastapy.math_utility import _1534
    from mastapy.math_utility.measured_data import _1565
    from mastapy.nodal_analysis.varying_input_components import _94, _95, _96, _97, _99


__docformat__ = "restructuredtext en"
__all__ = ("AbstractVaryingInputComponent",)


Self = TypeVar("Self", bound="AbstractVaryingInputComponent")


class AbstractVaryingInputComponent(_0.APIBase):
    """AbstractVaryingInputComponent

    This is a mastapy class.
    """

    TYPE = _ABSTRACT_VARYING_INPUT_COMPONENT
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_AbstractVaryingInputComponent")

    class _Cast_AbstractVaryingInputComponent:
        """Special nested class for casting AbstractVaryingInputComponent to subclasses."""

        def __init__(
            self: "AbstractVaryingInputComponent._Cast_AbstractVaryingInputComponent",
            parent: "AbstractVaryingInputComponent",
        ):
            self._parent = parent

        @property
        def angle_input_component(
            self: "AbstractVaryingInputComponent._Cast_AbstractVaryingInputComponent",
        ) -> "_94.AngleInputComponent":
            from mastapy.nodal_analysis.varying_input_components import _94

            return self._parent._cast(_94.AngleInputComponent)

        @property
        def force_input_component(
            self: "AbstractVaryingInputComponent._Cast_AbstractVaryingInputComponent",
        ) -> "_95.ForceInputComponent":
            from mastapy.nodal_analysis.varying_input_components import _95

            return self._parent._cast(_95.ForceInputComponent)

        @property
        def moment_input_component(
            self: "AbstractVaryingInputComponent._Cast_AbstractVaryingInputComponent",
        ) -> "_96.MomentInputComponent":
            from mastapy.nodal_analysis.varying_input_components import _96

            return self._parent._cast(_96.MomentInputComponent)

        @property
        def non_dimensional_input_component(
            self: "AbstractVaryingInputComponent._Cast_AbstractVaryingInputComponent",
        ) -> "_97.NonDimensionalInputComponent":
            from mastapy.nodal_analysis.varying_input_components import _97

            return self._parent._cast(_97.NonDimensionalInputComponent)

        @property
        def velocity_input_component(
            self: "AbstractVaryingInputComponent._Cast_AbstractVaryingInputComponent",
        ) -> "_99.VelocityInputComponent":
            from mastapy.nodal_analysis.varying_input_components import _99

            return self._parent._cast(_99.VelocityInputComponent)

        @property
        def abstract_varying_input_component(
            self: "AbstractVaryingInputComponent._Cast_AbstractVaryingInputComponent",
        ) -> "AbstractVaryingInputComponent":
            return self._parent

        def __getattr__(
            self: "AbstractVaryingInputComponent._Cast_AbstractVaryingInputComponent",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "AbstractVaryingInputComponent.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def include_values_before_zero_time(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.IncludeValuesBeforeZeroTime

        if temp is None:
            return False

        return temp

    @include_values_before_zero_time.setter
    @enforce_parameter_types
    def include_values_before_zero_time(self: Self, value: "bool"):
        self.wrapped.IncludeValuesBeforeZeroTime = (
            bool(value) if value is not None else False
        )

    @property
    def input_type(
        self: Self,
    ) -> "enum_with_selected_value.EnumWithSelectedValue_ValueInputOption":
        """EnumWithSelectedValue[mastapy.nodal_analysis.ValueInputOption]"""
        temp = self.wrapped.InputType

        if temp is None:
            return None

        value = (
            enum_with_selected_value.EnumWithSelectedValue_ValueInputOption.wrapped_type()
        )
        return enum_with_selected_value_runtime.create(temp, value)

    @input_type.setter
    @enforce_parameter_types
    def input_type(self: Self, value: "_91.ValueInputOption"):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = (
            enum_with_selected_value.EnumWithSelectedValue_ValueInputOption.implicit_type()
        )
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.InputType = value

    @property
    def single_point_selection_method_for_value_vs_time(
        self: Self,
    ) -> "enum_with_selected_value.EnumWithSelectedValue_SinglePointSelectionMethod":
        """EnumWithSelectedValue[mastapy.nodal_analysis.varying_input_components.SinglePointSelectionMethod]"""
        temp = self.wrapped.SinglePointSelectionMethodForValueVsTime

        if temp is None:
            return None

        value = (
            enum_with_selected_value.EnumWithSelectedValue_SinglePointSelectionMethod.wrapped_type()
        )
        return enum_with_selected_value_runtime.create(temp, value)

    @single_point_selection_method_for_value_vs_time.setter
    @enforce_parameter_types
    def single_point_selection_method_for_value_vs_time(
        self: Self, value: "_98.SinglePointSelectionMethod"
    ):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = (
            enum_with_selected_value.EnumWithSelectedValue_SinglePointSelectionMethod.implicit_type()
        )
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.SinglePointSelectionMethodForValueVsTime = value

    @property
    def time_profile_repeats(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.TimeProfileRepeats

        if temp is None:
            return False

        return temp

    @time_profile_repeats.setter
    @enforce_parameter_types
    def time_profile_repeats(self: Self, value: "bool"):
        self.wrapped.TimeProfileRepeats = bool(value) if value is not None else False

    @property
    def value_vs_angle(self: Self) -> "_1534.Vector2DListAccessor":
        """mastapy.math_utility.Vector2DListAccessor"""
        temp = self.wrapped.ValueVsAngle

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @value_vs_angle.setter
    @enforce_parameter_types
    def value_vs_angle(self: Self, value: "_1534.Vector2DListAccessor"):
        self.wrapped.ValueVsAngle = value.wrapped

    @property
    def value_vs_angle_and_speed(self: Self) -> "_1565.GriddedSurfaceAccessor":
        """mastapy.math_utility.measured_data.GriddedSurfaceAccessor"""
        temp = self.wrapped.ValueVsAngleAndSpeed

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @value_vs_angle_and_speed.setter
    @enforce_parameter_types
    def value_vs_angle_and_speed(self: Self, value: "_1565.GriddedSurfaceAccessor"):
        self.wrapped.ValueVsAngleAndSpeed = value.wrapped

    @property
    def value_vs_position(self: Self) -> "_1534.Vector2DListAccessor":
        """mastapy.math_utility.Vector2DListAccessor"""
        temp = self.wrapped.ValueVsPosition

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @value_vs_position.setter
    @enforce_parameter_types
    def value_vs_position(self: Self, value: "_1534.Vector2DListAccessor"):
        self.wrapped.ValueVsPosition = value.wrapped

    @property
    def value_vs_time(self: Self) -> "_1534.Vector2DListAccessor":
        """mastapy.math_utility.Vector2DListAccessor"""
        temp = self.wrapped.ValueVsTime

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @value_vs_time.setter
    @enforce_parameter_types
    def value_vs_time(self: Self, value: "_1534.Vector2DListAccessor"):
        self.wrapped.ValueVsTime = value.wrapped

    @property
    def report_names(self: Self) -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ReportNames

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    @enforce_parameter_types
    def output_default_report_to(self: Self, file_path: "str"):
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else "")

    def get_default_report_with_encoded_images(self: Self) -> "str":
        """str"""
        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_active_report_to(self: Self, file_path: "str"):
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else "")

    @enforce_parameter_types
    def output_active_report_as_text_to(self: Self, file_path: "str"):
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else "")

    def get_active_report_with_encoded_images(self: Self) -> "str":
        """str"""
        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_named_report_to(self: Self, report_name: "str", file_path: "str"):
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_masta_report(
        self: Self, report_name: "str", file_path: "str"
    ):
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_text_to(
        self: Self, report_name: "str", file_path: "str"
    ):
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def get_named_report_with_encoded_images(self: Self, report_name: "str") -> "str":
        """str

        Args:
            report_name (str)
        """
        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(
            report_name if report_name else ""
        )
        return method_result

    @property
    def cast_to(
        self: Self,
    ) -> "AbstractVaryingInputComponent._Cast_AbstractVaryingInputComponent":
        return self._Cast_AbstractVaryingInputComponent(self)



"""AdvancedTimeSteppingAnalysisForModulationType"""

from __future__ import annotations

from typing import TypeVar, Any
from enum import Enum

from mastapy._internal.python_net import python_net_import

_ADVANCED_TIME_STEPPING_ANALYSIS_FOR_MODULATION_TYPE = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads",
    "AdvancedTimeSteppingAnalysisForModulationType",
)


__docformat__ = "restructuredtext en"
__all__ = ("AdvancedTimeSteppingAnalysisForModulationType",)


Self = TypeVar("Self", bound="AdvancedTimeSteppingAnalysisForModulationType")


class AdvancedTimeSteppingAnalysisForModulationType(Enum):
    """AdvancedTimeSteppingAnalysisForModulationType

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls):
        return _ADVANCED_TIME_STEPPING_ANALYSIS_FOR_MODULATION_TYPE

    QUASI_HARMONIC_ANALYSIS = 0
    SEPARATION_OF_TIMESCALES_TIME_STEPPING = 1


def __enum_setattr(self: Self, attr: str, value: Any):
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: Self, attr: str):
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


AdvancedTimeSteppingAnalysisForModulationType.__setattr__ = __enum_setattr
AdvancedTimeSteppingAnalysisForModulationType.__delattr__ = __enum_delattr



"""FESubstructure"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, Union, Tuple, List, Optional

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal import constructor, conversion, enum_with_selected_value_runtime
from mastapy._internal.implicit import (
    list_with_selected_item,
    overridable,
    enum_with_selected_value,
)
from mastapy.system_model.part_model import _2444, _2448
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy.utility.units_and_measurements import _1610
from mastapy._internal.python_net import python_net_import
from mastapy.system_model.fe import _2411, _2388
from mastapy.nodal_analysis import _66
from mastapy._internal.cast_exception import CastException

_DATABASE_WITH_SELECTED_ITEM = python_net_import(
    "SMT.MastaAPI.UtilityGUI.Databases", "DatabaseWithSelectedItem"
)
_STRING = python_net_import("System", "String")
_TASK_PROGRESS = python_net_import("SMT.MastaAPIUtility", "TaskProgress")
_FE_SUBSTRUCTURE = python_net_import("SMT.MastaAPI.SystemModel.FE", "FESubstructure")

if TYPE_CHECKING:
    from mastapy.system_model.fe import (
        _2356,
        _2362,
        _2358,
        _2384,
        _2395,
        _2381,
        _2396,
        _2385,
        _2409,
        _2391,
        _2392,
        _2393,
        _2394,
    )
    from mastapy.nodal_analysis import _70, _85, _60
    from mastapy.nodal_analysis.component_mode_synthesis import _233, _226
    from mastapy.materials import _237, _283
    from mastapy.system_model import _2220
    from mastapy.math_utility import _1498
    from mastapy.system_model.part_model import _2453
    from mastapy.nodal_analysis.geometry_modeller_link import _155, _157
    from mastapy.system_model.fe.links import _2418
    from mastapy.system_model.part_model.shaft_model import _2482
    from mastapy.math_utility.measured_vectors import _1564
    from mastapy.nodal_analysis.fe_export_utility import _166
    from mastapy import _7559


__docformat__ = "restructuredtext en"
__all__ = ("FESubstructure",)


Self = TypeVar("Self", bound="FESubstructure")


class FESubstructure(_66.FEStiffness):
    """FESubstructure

    This is a mastapy class.
    """

    TYPE = _FE_SUBSTRUCTURE
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_FESubstructure")

    class _Cast_FESubstructure:
        """Special nested class for casting FESubstructure to subclasses."""

        def __init__(
            self: "FESubstructure._Cast_FESubstructure", parent: "FESubstructure"
        ):
            self._parent = parent

        @property
        def fe_stiffness(
            self: "FESubstructure._Cast_FESubstructure",
        ) -> "_66.FEStiffness":
            return self._parent._cast(_66.FEStiffness)

        @property
        def fe_substructure(
            self: "FESubstructure._Cast_FESubstructure",
        ) -> "FESubstructure":
            return self._parent

        def __getattr__(self: "FESubstructure._Cast_FESubstructure", name: str):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "FESubstructure.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def actual_number_of_rigid_body_modes(self: Self) -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ActualNumberOfRigidBodyModes

        if temp is None:
            return 0

        return temp

    @property
    def alignment_method(self: Self) -> "_2356.AlignmentMethod":
        """mastapy.system_model.fe.AlignmentMethod"""
        temp = self.wrapped.AlignmentMethod

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.SystemModel.FE.AlignmentMethod"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy.system_model.fe._2356", "AlignmentMethod"
        )(value)

    @alignment_method.setter
    @enforce_parameter_types
    def alignment_method(self: Self, value: "_2356.AlignmentMethod"):
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.SystemModel.FE.AlignmentMethod"
        )
        self.wrapped.AlignmentMethod = value

    @property
    def angle_span(self: Self) -> "float":
        """float"""
        temp = self.wrapped.AngleSpan

        if temp is None:
            return 0.0

        return temp

    @angle_span.setter
    @enforce_parameter_types
    def angle_span(self: Self, value: "float"):
        self.wrapped.AngleSpan = float(value) if value is not None else 0.0

    @property
    def angular_alignment_tolerance(self: Self) -> "float":
        """float"""
        temp = self.wrapped.AngularAlignmentTolerance

        if temp is None:
            return 0.0

        return temp

    @angular_alignment_tolerance.setter
    @enforce_parameter_types
    def angular_alignment_tolerance(self: Self, value: "float"):
        self.wrapped.AngularAlignmentTolerance = (
            float(value) if value is not None else 0.0
        )

    @property
    def apply_translation_and_rotation_for_planetary_duplicates(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.ApplyTranslationAndRotationForPlanetaryDuplicates

        if temp is None:
            return False

        return temp

    @apply_translation_and_rotation_for_planetary_duplicates.setter
    @enforce_parameter_types
    def apply_translation_and_rotation_for_planetary_duplicates(
        self: Self, value: "bool"
    ):
        self.wrapped.ApplyTranslationAndRotationForPlanetaryDuplicates = (
            bool(value) if value is not None else False
        )

    @property
    def are_vectors_loaded(self: Self) -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AreVectorsLoaded

        if temp is None:
            return False

        return temp

    @property
    def bearing_node_alignment(self: Self) -> "_2362.BearingNodeAlignmentOption":
        """mastapy.system_model.fe.BearingNodeAlignmentOption"""
        temp = self.wrapped.BearingNodeAlignment

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.SystemModel.FE.BearingNodeAlignmentOption"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy.system_model.fe._2362", "BearingNodeAlignmentOption"
        )(value)

    @bearing_node_alignment.setter
    @enforce_parameter_types
    def bearing_node_alignment(self: Self, value: "_2362.BearingNodeAlignmentOption"):
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.SystemModel.FE.BearingNodeAlignmentOption"
        )
        self.wrapped.BearingNodeAlignment = value

    @property
    def bearing_races_in_fe(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.BearingRacesInFE

        if temp is None:
            return False

        return temp

    @bearing_races_in_fe.setter
    @enforce_parameter_types
    def bearing_races_in_fe(self: Self, value: "bool"):
        self.wrapped.BearingRacesInFE = bool(value) if value is not None else False

    @property
    def check_fe_has_internal_modes_before_nvh_analysis(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.CheckFEHasInternalModesBeforeNVHAnalysis

        if temp is None:
            return False

        return temp

    @check_fe_has_internal_modes_before_nvh_analysis.setter
    @enforce_parameter_types
    def check_fe_has_internal_modes_before_nvh_analysis(self: Self, value: "bool"):
        self.wrapped.CheckFEHasInternalModesBeforeNVHAnalysis = (
            bool(value) if value is not None else False
        )

    @property
    def comment(self: Self) -> "str":
        """str"""
        temp = self.wrapped.Comment

        if temp is None:
            return ""

        return temp

    @comment.setter
    @enforce_parameter_types
    def comment(self: Self, value: "str"):
        self.wrapped.Comment = str(value) if value is not None else ""

    @property
    def component_to_align_to(
        self: Self,
    ) -> "list_with_selected_item.ListWithSelectedItem_Component":
        """ListWithSelectedItem[mastapy.system_model.part_model.Component]"""
        temp = self.wrapped.ComponentToAlignTo

        if temp is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_Component",
        )(temp)

    @component_to_align_to.setter
    @enforce_parameter_types
    def component_to_align_to(self: Self, value: "_2444.Component"):
        wrapper_type = (
            list_with_selected_item.ListWithSelectedItem_Component.wrapper_type()
        )
        enclosed_type = (
            list_with_selected_item.ListWithSelectedItem_Component.implicit_type()
        )
        value = wrapper_type[enclosed_type](
            value.wrapped if value is not None else None
        )
        self.wrapped.ComponentToAlignTo = value

    @property
    def condensation_node_size(self: Self) -> "float":
        """float"""
        temp = self.wrapped.CondensationNodeSize

        if temp is None:
            return 0.0

        return temp

    @condensation_node_size.setter
    @enforce_parameter_types
    def condensation_node_size(self: Self, value: "float"):
        self.wrapped.CondensationNodeSize = float(value) if value is not None else 0.0

    @property
    def datum(self: Self) -> "list_with_selected_item.ListWithSelectedItem_Datum":
        """ListWithSelectedItem[mastapy.system_model.part_model.Datum]"""
        temp = self.wrapped.Datum

        if temp is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_Datum",
        )(temp)

    @datum.setter
    @enforce_parameter_types
    def datum(self: Self, value: "_2448.Datum"):
        wrapper_type = list_with_selected_item.ListWithSelectedItem_Datum.wrapper_type()
        enclosed_type = (
            list_with_selected_item.ListWithSelectedItem_Datum.implicit_type()
        )
        value = wrapper_type[enclosed_type](
            value.wrapped if value is not None else None
        )
        self.wrapped.Datum = value

    @property
    def distance_display_unit(
        self: Self,
    ) -> "list_with_selected_item.ListWithSelectedItem_Unit":
        """ListWithSelectedItem[mastapy.utility.units_and_measurements.Unit]"""
        temp = self.wrapped.DistanceDisplayUnit

        if temp is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_Unit",
        )(temp)

    @distance_display_unit.setter
    @enforce_parameter_types
    def distance_display_unit(self: Self, value: "_1610.Unit"):
        wrapper_type = list_with_selected_item.ListWithSelectedItem_Unit.wrapper_type()
        enclosed_type = (
            list_with_selected_item.ListWithSelectedItem_Unit.implicit_type()
        )
        value = wrapper_type[enclosed_type](
            value.wrapped if value is not None else None
        )
        self.wrapped.DistanceDisplayUnit = value

    @property
    def expected_number_of_rigid_body_modes(
        self: Self,
    ) -> "overridable.Overridable_int":
        """Overridable[int]"""
        temp = self.wrapped.ExpectedNumberOfRigidBodyModes

        if temp is None:
            return 0

        return constructor.new_from_mastapy(
            "mastapy._internal.implicit.overridable", "Overridable_int"
        )(temp)

    @expected_number_of_rigid_body_modes.setter
    @enforce_parameter_types
    def expected_number_of_rigid_body_modes(
        self: Self, value: "Union[int, Tuple[int, bool]]"
    ):
        wrapper_type = overridable.Overridable_int.wrapper_type()
        enclosed_type = overridable.Overridable_int.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0, is_overridden
        )
        self.wrapped.ExpectedNumberOfRigidBodyModes = value

    @property
    def external_fe_forces_are_from_gravity_only(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.ExternalFEForcesAreFromGravityOnly

        if temp is None:
            return False

        return temp

    @external_fe_forces_are_from_gravity_only.setter
    @enforce_parameter_types
    def external_fe_forces_are_from_gravity_only(self: Self, value: "bool"):
        self.wrapped.ExternalFEForcesAreFromGravityOnly = (
            bool(value) if value is not None else False
        )

    @property
    def force_display_unit(
        self: Self,
    ) -> "list_with_selected_item.ListWithSelectedItem_Unit":
        """ListWithSelectedItem[mastapy.utility.units_and_measurements.Unit]"""
        temp = self.wrapped.ForceDisplayUnit

        if temp is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_Unit",
        )(temp)

    @force_display_unit.setter
    @enforce_parameter_types
    def force_display_unit(self: Self, value: "_1610.Unit"):
        wrapper_type = list_with_selected_item.ListWithSelectedItem_Unit.wrapper_type()
        enclosed_type = (
            list_with_selected_item.ListWithSelectedItem_Unit.implicit_type()
        )
        value = wrapper_type[enclosed_type](
            value.wrapped if value is not None else None
        )
        self.wrapped.ForceDisplayUnit = value

    @property
    def full_fe_model_mesh_path(self: Self) -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FullFEModelMeshPath

        if temp is None:
            return ""

        return temp

    @property
    def full_fe_model_mesh_size(self: Self) -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FullFEModelMeshSize

        if temp is None:
            return ""

        return temp

    @property
    def full_fe_model_vectors_path(self: Self) -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FullFEModelVectorsPath

        if temp is None:
            return ""

        return temp

    @property
    def full_fe_model_vectors_size(self: Self) -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FullFEModelVectorsSize

        if temp is None:
            return ""

        return temp

    @property
    def geometry_meshing_material(self: Self) -> "str":
        """str"""
        temp = self.wrapped.GeometryMeshingMaterial.SelectedItemName

        if temp is None:
            return ""

        return temp

    @geometry_meshing_material.setter
    @enforce_parameter_types
    def geometry_meshing_material(self: Self, value: "str"):
        self.wrapped.GeometryMeshingMaterial.SetSelectedItem(
            str(value) if value is not None else ""
        )

    @property
    def gravity_force_can_be_rotated(self: Self) -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GravityForceCanBeRotated

        if temp is None:
            return False

        return temp

    @property
    def gravity_force_source(self: Self) -> "_70.GravityForceSource":
        """mastapy.nodal_analysis.GravityForceSource

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GravityForceSource

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.NodalAnalysis.GravityForceSource"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy.nodal_analysis._70", "GravityForceSource"
        )(value)

    @property
    def gravity_magnitude_used_for_reduced_forces(self: Self) -> "float":
        """float"""
        temp = self.wrapped.GravityMagnitudeUsedForReducedForces

        if temp is None:
            return 0.0

        return temp

    @gravity_magnitude_used_for_reduced_forces.setter
    @enforce_parameter_types
    def gravity_magnitude_used_for_reduced_forces(self: Self, value: "float"):
        self.wrapped.GravityMagnitudeUsedForReducedForces = (
            float(value) if value is not None else 0.0
        )

    @property
    def housing_is_grounded(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.HousingIsGrounded

        if temp is None:
            return False

        return temp

    @housing_is_grounded.setter
    @enforce_parameter_types
    def housing_is_grounded(self: Self, value: "bool"):
        self.wrapped.HousingIsGrounded = bool(value) if value is not None else False

    @property
    def is_housing(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.IsHousing

        if temp is None:
            return False

        return temp

    @is_housing.setter
    @enforce_parameter_types
    def is_housing(self: Self, value: "bool"):
        self.wrapped.IsHousing = bool(value) if value is not None else False

    @property
    def is_mesh_loaded(self: Self) -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        temp = self.wrapped.IsMeshLoaded

        if temp is None:
            return False

        return temp

    @property
    def material(self: Self) -> "str":
        """str"""
        temp = self.wrapped.Material.SelectedItemName

        if temp is None:
            return ""

        return temp

    @material.setter
    @enforce_parameter_types
    def material(self: Self, value: "str"):
        self.wrapped.Material.SetSelectedItem(str(value) if value is not None else "")

    @property
    def non_condensation_node_size(self: Self) -> "int":
        """int"""
        temp = self.wrapped.NonCondensationNodeSize

        if temp is None:
            return 0

        return temp

    @non_condensation_node_size.setter
    @enforce_parameter_types
    def non_condensation_node_size(self: Self, value: "int"):
        self.wrapped.NonCondensationNodeSize = int(value) if value is not None else 0

    @property
    def number_of_angles(self: Self) -> "int":
        """int"""
        temp = self.wrapped.NumberOfAngles

        if temp is None:
            return 0

        return temp

    @number_of_angles.setter
    @enforce_parameter_types
    def number_of_angles(self: Self, value: "int"):
        self.wrapped.NumberOfAngles = int(value) if value is not None else 0

    @property
    def number_of_condensation_nodes(self: Self) -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfCondensationNodes

        if temp is None:
            return 0

        return temp

    @property
    def number_of_condensation_nodes_in_reduced_model(self: Self) -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfCondensationNodesInReducedModel

        if temp is None:
            return 0

        return temp

    @property
    def polar_inertia(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PolarInertia

        if temp is None:
            return 0.0

        return temp

    @property
    def reduced_stiffness_file(self: Self) -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ReducedStiffnessFile

        if temp is None:
            return ""

        return temp

    @property
    def reduced_stiffness_file_editable(self: Self) -> "str":
        """str"""
        temp = self.wrapped.ReducedStiffnessFileEditable

        if temp is None:
            return ""

        return temp

    @reduced_stiffness_file_editable.setter
    @enforce_parameter_types
    def reduced_stiffness_file_editable(self: Self, value: "str"):
        self.wrapped.ReducedStiffnessFileEditable = (
            str(value) if value is not None else ""
        )

    @property
    def reduction_mode_type(self: Self) -> "_233.ReductionModeType":
        """mastapy.nodal_analysis.component_mode_synthesis.ReductionModeType"""
        temp = self.wrapped.ReductionModeType

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.NodalAnalysis.ComponentModeSynthesis.ReductionModeType"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy.nodal_analysis.component_mode_synthesis._233", "ReductionModeType"
        )(value)

    @reduction_mode_type.setter
    @enforce_parameter_types
    def reduction_mode_type(self: Self, value: "_233.ReductionModeType"):
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.NodalAnalysis.ComponentModeSynthesis.ReductionModeType"
        )
        self.wrapped.ReductionModeType = value

    @property
    def thermal_expansion_option(
        self: Self,
    ) -> "enum_with_selected_value.EnumWithSelectedValue_ThermalExpansionOption":
        """EnumWithSelectedValue[mastapy.system_model.fe.ThermalExpansionOption]"""
        temp = self.wrapped.ThermalExpansionOption

        if temp is None:
            return None

        value = (
            enum_with_selected_value.EnumWithSelectedValue_ThermalExpansionOption.wrapped_type()
        )
        return enum_with_selected_value_runtime.create(temp, value)

    @thermal_expansion_option.setter
    @enforce_parameter_types
    def thermal_expansion_option(self: Self, value: "_2411.ThermalExpansionOption"):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = (
            enum_with_selected_value.EnumWithSelectedValue_ThermalExpansionOption.implicit_type()
        )
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.ThermalExpansionOption = value

    @property
    def torque_transmission_relative_tolerance(self: Self) -> "float":
        """float"""
        temp = self.wrapped.TorqueTransmissionRelativeTolerance

        if temp is None:
            return 0.0

        return temp

    @torque_transmission_relative_tolerance.setter
    @enforce_parameter_types
    def torque_transmission_relative_tolerance(self: Self, value: "float"):
        self.wrapped.TorqueTransmissionRelativeTolerance = (
            float(value) if value is not None else 0.0
        )

    @property
    def type_(
        self: Self,
    ) -> "enum_with_selected_value.EnumWithSelectedValue_FESubstructureType":
        """EnumWithSelectedValue[mastapy.system_model.fe.FESubstructureType]"""
        temp = self.wrapped.Type

        if temp is None:
            return None

        value = (
            enum_with_selected_value.EnumWithSelectedValue_FESubstructureType.wrapped_type()
        )
        return enum_with_selected_value_runtime.create(temp, value)

    @type_.setter
    @enforce_parameter_types
    def type_(self: Self, value: "_2388.FESubstructureType"):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = (
            enum_with_selected_value.EnumWithSelectedValue_FESubstructureType.implicit_type()
        )
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.Type = value

    @property
    def acoustic_radiation_efficiency(self: Self) -> "_237.AcousticRadiationEfficiency":
        """mastapy.materials.AcousticRadiationEfficiency

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AcousticRadiationEfficiency

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def alignment_using_axial_node_positions(
        self: Self,
    ) -> "_2358.AlignmentUsingAxialNodePositions":
        """mastapy.system_model.fe.AlignmentUsingAxialNodePositions

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AlignmentUsingAxialNodePositions

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def alignment_to_component(
        self: Self,
    ) -> "_2220.RelativeComponentAlignment[_2444.Component]":
        """mastapy.system_model.RelativeComponentAlignment[mastapy.system_model.part_model.Component]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AlignmentToComponent

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)[_2444.Component](temp)

    @property
    def cms_model(self: Self) -> "_226.CMSModel":
        """mastapy.nodal_analysis.component_mode_synthesis.CMSModel

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CMSModel

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def coordinate_system(self: Self) -> "_1498.CoordinateSystem3D":
        """mastapy.math_utility.CoordinateSystem3D

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CoordinateSystem

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def export(self: Self) -> "_2384.FESubstructureExportOptions":
        """mastapy.system_model.fe.FESubstructureExportOptions

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Export

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def fe_meshing_options(self: Self) -> "_85.ShaftFEMeshingOptions":
        """mastapy.nodal_analysis.ShaftFEMeshingOptions

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FEMeshingOptions

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def fe_part(self: Self) -> "_2453.FEPart":
        """mastapy.system_model.part_model.FEPart

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FEPart

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def geometry_modeller_design_information(
        self: Self,
    ) -> "_155.GeometryModellerDesignInformation":
        """mastapy.nodal_analysis.geometry_modeller_link.GeometryModellerDesignInformation

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GeometryModellerDesignInformation

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def geometry_modeller_dimensions(self: Self) -> "_157.GeometryModellerDimensions":
        """mastapy.nodal_analysis.geometry_modeller_link.GeometryModellerDimensions

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GeometryModellerDimensions

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def sound_pressure_enclosure(self: Self) -> "_283.SoundPressureEnclosure":
        """mastapy.materials.SoundPressureEnclosure

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SoundPressureEnclosure

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def gear_meshing_options(self: Self) -> "List[_2395.GearMeshingOptions]":
        """List[mastapy.system_model.fe.GearMeshingOptions]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GearMeshingOptions

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def geometries(self: Self) -> "List[_2381.FEStiffnessGeometry]":
        """List[mastapy.system_model.fe.FEStiffnessGeometry]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Geometries

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def independent_masta_created_condensation_nodes(
        self: Self,
    ) -> "List[_2396.IndependentMASTACreatedCondensationNode]":
        """List[mastapy.system_model.fe.IndependentMASTACreatedCondensationNode]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.IndependentMastaCreatedCondensationNodes

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def links(self: Self) -> "List[_2418.FELink]":
        """List[mastapy.system_model.fe.links.FELink]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Links

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def nodes(self: Self) -> "List[_2385.FESubstructureNode]":
        """List[mastapy.system_model.fe.FESubstructureNode]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Nodes

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def replaced_shafts(self: Self) -> "List[_2482.Shaft]":
        """List[mastapy.system_model.part_model.shaft_model.Shaft]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ReplacedShafts

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def shafts_that_can_be_replaced(
        self: Self,
    ) -> "List[_2409.ReplacedShaftSelectionHelper]":
        """List[mastapy.system_model.fe.ReplacedShaftSelectionHelper]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ShaftsThatCanBeReplaced

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def thermal_expansion_displacements(
        self: Self,
    ) -> "List[_1564.VectorWithLinearAndAngularComponents]":
        """List[mastapy.math_utility.measured_vectors.VectorWithLinearAndAngularComponents]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ThermalExpansionDisplacements

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def thermal_expansion_forces(
        self: Self,
    ) -> "List[_1564.VectorWithLinearAndAngularComponents]":
        """List[mastapy.math_utility.measured_vectors.VectorWithLinearAndAngularComponents]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ThermalExpansionForces

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def name(self: Self) -> "str":
        """str"""
        temp = self.wrapped.Name

        if temp is None:
            return ""

        return temp

    @name.setter
    @enforce_parameter_types
    def name(self: Self, value: "str"):
        self.wrapped.Name = str(value) if value is not None else ""

    def add_geometry(self: Self):
        """Method does not return."""
        self.wrapped.AddGeometry()

    def auto_connect_external_nodes(self: Self):
        """Method does not return."""
        self.wrapped.AutoConnectExternalNodes()

    def copy_datum_to_manual(self: Self):
        """Method does not return."""
        self.wrapped.CopyDatumToManual()

    def create_datum_from_manual_alignment(self: Self):
        """Method does not return."""
        self.wrapped.CreateDatumFromManualAlignment()

    def create_fe_volume_mesh(self: Self):
        """Method does not return."""
        self.wrapped.CreateFEVolumeMesh()

    def default_node_creation_options(self: Self):
        """Method does not return."""
        self.wrapped.DefaultNodeCreationOptions()

    def delete_all_links(self: Self):
        """Method does not return."""
        self.wrapped.DeleteAllLinks()

    def embed_fe_model_mesh_in_masta_file(self: Self):
        """Method does not return."""
        self.wrapped.EmbedFEModelMeshInMASTAFile()

    def embed_fe_model_vectors_in_masta_file(self: Self):
        """Method does not return."""
        self.wrapped.EmbedFEModelVectorsInMASTAFile()

    def perform_reduction(self: Self):
        """Method does not return."""
        self.wrapped.PerformReduction()

    def re_import_external_fe_mesh(self: Self):
        """Method does not return."""
        self.wrapped.ReImportExternalFEMesh()

    def remove_full_fe_mesh(self: Self):
        """Method does not return."""
        self.wrapped.RemoveFullFEMesh()

    def reread_mesh_from_geometry_modeller(self: Self):
        """Method does not return."""
        self.wrapped.RereadMeshFromGeometryModeller()

    def unload_external_mesh_file(self: Self):
        """Method does not return."""
        self.wrapped.UnloadExternalMeshFile()

    def unload_external_vectors_file(self: Self):
        """Method does not return."""
        self.wrapped.UnloadExternalVectorsFile()

    def update_gear_teeth_mesh(self: Self):
        """Method does not return."""
        self.wrapped.UpdateGearTeethMesh()

    @enforce_parameter_types
    def convert_shafts_to_fe(
        self: Self, operation: "_60.FEMeshingOperation", export_file_name: "str"
    ):
        """Method does not return.

        Args:
            operation (mastapy.nodal_analysis.FEMeshingOperation)
            export_file_name (str)
        """
        operation = conversion.mp_to_pn_enum(
            operation, "SMT.MastaAPI.NodalAnalysis.FEMeshingOperation"
        )
        export_file_name = str(export_file_name)
        self.wrapped.ConvertShaftsToFE(
            operation, export_file_name if export_file_name else ""
        )

    def create_fe_substructure_with_selection_components(
        self: Self,
    ) -> "_2391.FESubstructureWithSelectionComponents":
        """mastapy.system_model.fe.FESubstructureWithSelectionComponents"""
        method_result = self.wrapped.CreateFESubstructureWithSelectionComponents()
        type_ = method_result.GetType()
        return (
            constructor.new(type_.Namespace, type_.Name)(method_result)
            if method_result is not None
            else None
        )

    def create_fe_substructure_with_selection_for_harmonic_analysis(
        self: Self,
    ) -> "_2392.FESubstructureWithSelectionForHarmonicAnalysis":
        """mastapy.system_model.fe.FESubstructureWithSelectionForHarmonicAnalysis"""
        method_result = (
            self.wrapped.CreateFESubstructureWithSelectionForHarmonicAnalysis()
        )
        type_ = method_result.GetType()
        return (
            constructor.new(type_.Namespace, type_.Name)(method_result)
            if method_result is not None
            else None
        )

    def create_fe_substructure_with_selection_for_modal_analysis(
        self: Self,
    ) -> "_2393.FESubstructureWithSelectionForModalAnalysis":
        """mastapy.system_model.fe.FESubstructureWithSelectionForModalAnalysis"""
        method_result = self.wrapped.CreateFESubstructureWithSelectionForModalAnalysis()
        type_ = method_result.GetType()
        return (
            constructor.new(type_.Namespace, type_.Name)(method_result)
            if method_result is not None
            else None
        )

    def create_fe_substructure_with_selection_for_static_analysis(
        self: Self,
    ) -> "_2394.FESubstructureWithSelectionForStaticAnalysis":
        """mastapy.system_model.fe.FESubstructureWithSelectionForStaticAnalysis"""
        method_result = (
            self.wrapped.CreateFESubstructureWithSelectionForStaticAnalysis()
        )
        type_ = method_result.GetType()
        return (
            constructor.new(type_.Namespace, type_.Name)(method_result)
            if method_result is not None
            else None
        )

    @enforce_parameter_types
    def duplicate(self: Self, name: "str") -> "FESubstructure":
        """mastapy.system_model.fe.FESubstructure

        Args:
            name (str)
        """
        name = str(name)
        method_result = self.wrapped.Duplicate(name if name else "")
        type_ = method_result.GetType()
        return (
            constructor.new(type_.Namespace, type_.Name)(method_result)
            if method_result is not None
            else None
        )

    @enforce_parameter_types
    def import_fe_mesh(
        self: Self,
        file_path: "str",
        format_: "_166.FEExportFormat",
        length_scale: "float" = 1.0,
        force_scale: "float" = 1.0,
        progress: Optional["_7559.TaskProgress"] = None,
    ):
        """Method does not return.

        Args:
            file_path (str)
            format_ (mastapy.nodal_analysis.fe_export_utility.FEExportFormat)
            length_scale (float, optional)
            force_scale (float, optional)
            progress (mastapy.TaskProgress, optional)
        """
        file_path = str(file_path)
        format_ = conversion.mp_to_pn_enum(
            format_, "SMT.MastaAPI.NodalAnalysis.FeExportUtility.FEExportFormat"
        )
        length_scale = float(length_scale)
        force_scale = float(force_scale)
        self.wrapped.ImportFEMesh(
            file_path if file_path else "",
            format_,
            length_scale if length_scale else 0.0,
            force_scale if force_scale else 0.0,
            progress.wrapped if progress else None,
        )

    @enforce_parameter_types
    def import_node_positions(
        self: Self, file_name: "str", distance_unit: "_1610.Unit"
    ):
        """Method does not return.

        Args:
            file_name (str)
            distance_unit (mastapy.utility.units_and_measurements.Unit)
        """
        file_name = str(file_name)
        self.wrapped.ImportNodePositions(
            file_name if file_name else "",
            distance_unit.wrapped if distance_unit else None,
        )

    @enforce_parameter_types
    def import_reduced_stiffness(
        self: Self,
        file_name: "str",
        distance_unit: "_1610.Unit",
        force_unit: "_1610.Unit",
    ):
        """Method does not return.

        Args:
            file_name (str)
            distance_unit (mastapy.utility.units_and_measurements.Unit)
            force_unit (mastapy.utility.units_and_measurements.Unit)
        """
        file_name = str(file_name)
        self.wrapped.ImportReducedStiffness(
            file_name if file_name else "",
            distance_unit.wrapped if distance_unit else None,
            force_unit.wrapped if force_unit else None,
        )

    @enforce_parameter_types
    def links_for(self: Self, node: "_2385.FESubstructureNode") -> "List[_2418.FELink]":
        """List[mastapy.system_model.fe.links.FELink]

        Args:
            node (mastapy.system_model.fe.FESubstructureNode)
        """
        return conversion.pn_to_mp_objects_in_list(
            self.wrapped.LinksFor(node.wrapped if node else None)
        )

    @enforce_parameter_types
    def load_existing_masta_fe_file(self: Self, file_name: "str"):
        """Method does not return.

        Args:
            file_name (str)
        """
        file_name = str(file_name)
        self.wrapped.LoadExistingMastaFEFile.Overloads[_STRING](
            file_name if file_name else ""
        )

    @enforce_parameter_types
    def load_existing_masta_fe_file_with_progress(
        self: Self, file_name: "str", progress: "_7559.TaskProgress"
    ):
        """Method does not return.

        Args:
            file_name (str)
            progress (mastapy.TaskProgress)
        """
        file_name = str(file_name)
        self.wrapped.LoadExistingMastaFEFile.Overloads[_STRING, _TASK_PROGRESS](
            file_name if file_name else "", progress.wrapped if progress else None
        )

    @enforce_parameter_types
    def load_external_mesh(self: Self, file_path: "str"):
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.LoadExternalMesh(file_path if file_path else "")

    @enforce_parameter_types
    def load_external_vectors(self: Self, file_path: "str"):
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.LoadExternalVectors(file_path if file_path else "")

    @enforce_parameter_types
    def load_stl_geometry(self: Self, length_unit: "_1610.Unit", file_name: "str"):
        """Method does not return.

        Args:
            length_unit (mastapy.utility.units_and_measurements.Unit)
            file_name (str)
        """
        file_name = str(file_name)
        self.wrapped.LoadStlGeometry(
            length_unit.wrapped if length_unit else None, file_name if file_name else ""
        )

    @enforce_parameter_types
    def store_full_fe_mesh_in_external_file(self: Self, external_fe_path: "str"):
        """Method does not return.

        Args:
            external_fe_path (str)
        """
        external_fe_path = str(external_fe_path)
        self.wrapped.StoreFullFeMeshInExternalFile(
            external_fe_path if external_fe_path else ""
        )

    @enforce_parameter_types
    def store_full_fe_model_vectors_in_external_file(
        self: Self, external_fe_path: "str"
    ):
        """Method does not return.

        Args:
            external_fe_path (str)
        """
        external_fe_path = str(external_fe_path)
        self.wrapped.StoreFullFeModelVectorsInExternalFile(
            external_fe_path if external_fe_path else ""
        )

    @property
    def cast_to(self: Self) -> "FESubstructure._Cast_FESubstructure":
        return self._Cast_FESubstructure(self)
